@@ -41,16 +41,17 @@ def info(node_or_path, max_rows=DEFAULT_MAX_ROWS, max_cols=DEFAULT_MAX_COLS, sho
     """
     with _manage_node(node_or_path) as node:
         lines = render_tree(node, max_rows=max_rows, max_cols=max_cols, show_values=show_values, identifier="root")
-        print("\n".join(lines))
+        print("\n".join(lines))  # noqa: T201
 
 
 @contextmanager
 def _manage_node(node_or_path):
-    if isinstance(node_or_path, str) or isinstance(node_or_path, pathlib.Path):
+    if isinstance(node_or_path, (str, pathlib.Path)):
         with open_asdf(node_or_path) as af:
             yield af.tree
+
+    elif isinstance(node_or_path, AsdfFile):
+        yield node_or_path.tree
+
     else:
-        if isinstance(node_or_path, AsdfFile):
-            yield node_or_path.tree
-        else:
-            yield node_or_path
+        yield node_or_path
