@@ -36,7 +36,7 @@ def render_tree(
     max_rows=DEFAULT_MAX_ROWS,
     max_cols=DEFAULT_MAX_COLS,
     show_values=DEFAULT_SHOW_VALUES,
-    filters=[],
+    filters=None,
     identifier="root",
     refresh_extension_manager=False,
 ):
@@ -47,7 +47,7 @@ def render_tree(
         key="title",
         node=node,
         identifier=identifier,
-        filters=filters,
+        filters=[] if filters is None else filters,
         refresh_extension_manager=refresh_extension_manager,
     )
     if info is None:
@@ -158,7 +158,7 @@ class _TreeRenderer:
         Select nodes to display, obeying the per-node max_rows value for
         each tree depth.
         """
-        max_rows = (None,) + self._max_rows
+        max_rows = (None, *self._max_rows)
 
         current_infos = [root_info]
         while True:
@@ -229,10 +229,11 @@ class _TreeRenderer:
         prefix = self._make_prefix(info.depth, active_depths, is_tail)
         value = self._render_node_value(info)
 
-        if isinstance(info.parent_node, list) or isinstance(info.parent_node, tuple):
-            line = f"{prefix}[{format_bold(info.identifier)}] {value}"
-        else:
-            line = f"{prefix}{format_bold(info.identifier)} {value}"
+        line = (
+            f"{prefix}[{format_bold(info.identifier)}] {value}"
+            if isinstance(info.parent_node, (list, tuple))
+            else f"{prefix}{format_bold(info.identifier)} {value}"
+        )
 
         if info.info is not None:
             line = line + format_faint(format_italic(" # " + info.info))
@@ -253,10 +254,11 @@ class _TreeRenderer:
         rendered_type = type(info.node).__name__
         if is_primitive(info.node) and self._show_values:
             return f"({rendered_type}): {info.node}"
-        elif isinstance(info.node, NDArrayType) or isinstance(info.node, np.ndarray):
+
+        if isinstance(info.node, (NDArrayType, np.ndarray)):
             return f"({rendered_type}): shape={info.node.shape}, dtype={info.node.dtype.name}"
-        else:
-            return f"({rendered_type})"
+
+        return f"({rendered_type})"
 
     def _make_prefix(self, depth, active_depths, is_tail):
         """
@@ -270,14 +272,8 @@ class _TreeRenderer:
 
         if depth >= 2:
             for n in range(0, depth - 1):
-                if n in active_depths:
-                    prefix = prefix + "│ "
-                else:
-                    prefix = prefix + "  "
+                prefix = prefix + "│ " if n in active_depths else prefix + "  "
 
-        if is_tail:
-            prefix = prefix + "└─"
-        else:
-            prefix = prefix + "├─"
+        prefix = prefix + "└─" if is_tail else prefix + "├─"
 
         return format_faint(prefix)
