@@ -21,7 +21,7 @@ class BlockManager:
     Manages the `Block`s associated with a ASDF file.
     """
 
-    def __init__(self, asdffile, copy_arrays=False, lazy_load=True, readonly=False):
+    def __init__(self, asdffile, copy_arrays=False, lazy_load=True):
         self._asdffile = weakref.ref(asdffile)
 
         self._internal_blocks = []
@@ -40,7 +40,6 @@ class BlockManager:
         self._validate_checksums = False
         self._memmap = not copy_arrays
         self._lazy_load = lazy_load
-        self._readonly = readonly
         self._internal_blocks_mapped = False
 
     def __len__(self):
@@ -72,10 +71,12 @@ class BlockManager:
             if block not in block_set:
                 block_set.append(block)
         else:
-            raise ValueError(f"Unknown array storage type {block.array_storage}")
+            msg = f"Unknown array storage type {block.array_storage}"
+            raise ValueError(msg)
 
         if block.array_storage == "streamed" and len(self._streamed_blocks) > 1:
-            raise ValueError("Can not add second streaming block")
+            msg = "Can not add second streaming block"
+            raise ValueError(msg)
 
         if block._data is not None:
             self._data_to_block_mapping[id(block._data)] = block
@@ -88,11 +89,12 @@ class BlockManager:
         if block_set is not None:
             if block in block_set:
                 block_set.remove(block)
-                if block._data is not None:
-                    if id(block._data) in self._data_to_block_mapping:
-                        del self._data_to_block_mapping[id(block._data)]
+                if block._data is not None and id(block._data) in self._data_to_block_mapping:
+                    del self._data_to_block_mapping[id(block._data)]
+
         else:
-            raise ValueError(f"Unknown array storage type {block.array_storage}")
+            msg = f"Unknown array storage type {block.array_storage}"
+            raise ValueError(msg)
 
     def set_array_storage(self, block, array_storage):
         """
@@ -117,7 +119,8 @@ class BlockManager:
               appears at the end of the file.
         """
         if array_storage not in ["internal", "external", "streamed", "inline"]:
-            raise ValueError("array_storage must be one of 'internal', 'external', 'streamed' or 'inline'")
+            msg = "array_storage must be one of 'internal', 'external', 'streamed' or 'inline'"
+            raise ValueError(msg)
 
         if block.array_storage != array_storage:
             if block in self.blocks:
@@ -165,6 +168,8 @@ class BlockManager:
         if len(self._streamed_blocks):
             return self._streamed_blocks[0]
 
+        return None
+
     @property
     def external_blocks(self):
         """
@@ -199,10 +204,7 @@ class BlockManager:
         Returns `True` if any of the internal blocks currently have an
         offset assigned.
         """
-        for block in self.internal_blocks:
-            if block.offset is not None:
-                return True
-        return False
+        return any(block.offset is not None for block in self.internal_blocks)
 
     def _new_block(self):
         return Block(memmap=self.memmap, lazy_load=self.lazy_load)
@@ -210,9 +212,10 @@ class BlockManager:
     def _sort_blocks_by_offset(self):
         def sorter(x):
             if x.offset is None:
-                raise ValueError("Block is missing offset")
-            else:
-                return x.offset
+                msg = "Block is missing offset"
+                raise ValueError(msg)
+
+            return x.offset
 
         self._internal_blocks.sort(key=sorter)
 
@@ -268,7 +271,7 @@ class BlockManager:
         """
         if not self._internal_blocks:
             return
-        for i, block in enumerate(self._internal_blocks):
+        for block in self._internal_blocks:
             if isinstance(block, UnloadedBlock):
                 block.load()
 
@@ -320,15 +323,15 @@ class BlockManager:
         """
         self._sort_blocks_by_offset()
 
-        iter = self.internal_blocks
-        last_block = next(iter)
+        iter_ = self.internal_blocks
+        last_block = next(iter_)
         # We need to explicitly clear anything between the tree
         # and the first block, otherwise there may be other block
         # markers left over which will throw off block indexing.
         # We don't need to do this between each block.
         fd.clear(last_block.offset - fd.tell())
 
-        for block in iter:
+        for block in iter_:
             last_block.allocated = (block.offset - last_block.offset) - last_block.header_size
             fd.seek(last_block.offset)
             last_block.write(fd)
@@ -353,13 +356,14 @@ class BlockManager:
 
         for i, block in enumerate(self.external_blocks):
             if uri is None:
-                raise ValueError("Can't write external blocks, since URI of main file is unknown.")
+                msg = "Can't write external blocks, since URI of main file is unknown."
+                raise ValueError(msg)
             subfd = self.get_external_uri(uri, i)
             asdffile = asdf.AsdfFile()
-            block = copy.copy(block)
-            block._array_storage = "internal"
-            asdffile.blocks.add(block)
-            block._used = True
+            blk = copy.copy(block)
+            blk._array_storage = "internal"
+            asdffile._blocks.add(blk)
+            blk._used = True
             asdffile.write_to(subfd, pad_blocks=pad_blocks)
 
     def write_block_index(self, fd, ctx):
@@ -453,11 +457,11 @@ class BlockManager:
                 content = content[idx:]
                 index_start = block_start + idx
                 break
-            else:
-                # If the rest of it starts to look like binary
-                # values, bail...
-                if not self._re_index_misc.match(buff):
-                    return
+
+            # If the rest of it starts to look like binary
+            # values, bail...
+            if not self._re_index_misc.match(buff):
+                return
 
             if block_start <= first_block_end:
                 return
@@ -474,7 +478,7 @@ class BlockManager:
 
         # The following call to yaml.load is safe because we're
         # using pyyaml's SafeLoader.
-        offsets = yaml.load(yaml_content, Loader=yamlutil._yaml_base_loader)  # nosec
+        offsets = yaml.load(yaml_content, Loader=yamlutil._yaml_base_loader)  # noqa: S506
 
         # Make sure the indices look sane
         if not isinstance(offsets, list) or len(offsets) == 0:
@@ -512,9 +516,7 @@ class BlockManager:
         # It seems we're good to go, so instantiate the UnloadedBlock
         # objects
         for offset in offsets[1:-1]:
-            self._internal_blocks.append(
-                UnloadedBlock(fd, offset, memmap=self.memmap, lazy_load=self.lazy_load, readonly=self._readonly)
-            )
+            self._internal_blocks.append(UnloadedBlock(fd, offset, memmap=self.memmap, lazy_load=self.lazy_load))
 
         # We already read the last block in the file -- no need to read it again
         self._internal_blocks.append(block)
@@ -554,10 +556,12 @@ class BlockManager:
         reserved_blocks = set()
 
         for node in treeutil.iter_tree(tree):
-            hook = ctx.type_index.get_hook_for_type("reserve_blocks", type(node), ctx.version_string)
-            if hook is not None:
-                for block in hook(node, ctx):
-                    reserved_blocks.add(block)
+            # check that this object will not be handled by a converter
+            if not ctx.extension_manager.handles_type(type(node)):
+                hook = ctx._type_index.get_hook_for_type("reserve_blocks", type(node), ctx.version_string)
+                if hook is not None:
+                    for block in hook(node, ctx):
+                        reserved_blocks.add(block)
 
         for block in list(self.blocks):
             if getattr(block, "_used", 0) == 0 and block not in reserved_blocks:
@@ -579,7 +583,7 @@ class BlockManager:
         if all_array_storage is None:
             threshold = get_config().array_inline_threshold
             if threshold is not None and block.array_storage in ["internal", "inline"]:
-                if np.product(block.data.shape) < threshold:
+                if np.prod(block.data.shape) < threshold:
                     self.set_array_storage(block, "inline")
                 else:
                     self.set_array_storage(block, "internal")
@@ -628,13 +632,15 @@ class BlockManager:
                 if source < len(self._internal_blocks):
                     return self._internal_blocks[source]
             else:
-                raise ValueError(f"Invalid source id {source}")
+                msg = f"Invalid source id {source}"
+                raise ValueError(msg)
 
             # If we have a streamed block or we already know we have
             # no blocks, reading any further isn't going to yield any
             # new blocks.
             if len(self._streamed_blocks) or len(self._internal_blocks) == 0:
-                raise ValueError(f"Block '{source}' not found.")
+                msg = f"Block '{source}' not found."
+                raise ValueError(msg)
 
             # If the desired block hasn't already been read, and the
             # file is seekable, and we have at least one internal
@@ -656,11 +662,12 @@ class BlockManager:
             if source == -1 and last_block.array_storage == "streamed":
                 return last_block
 
-            raise ValueError(f"Block '{source}' not found.")
+            msg = f"Block '{source}' not found."
+            raise ValueError(msg)
 
-        elif isinstance(source, str):
+        if isinstance(source, str):
             asdffile = self._asdffile().open_external(source)
-            block = asdffile.blocks._internal_blocks[0]
+            block = asdffile._blocks._internal_blocks[0]
             self.set_array_storage(block, "external")
 
         # Handle the case of inline data
@@ -668,7 +675,8 @@ class BlockManager:
             block = Block(data=np.array(source), array_storage="inline")
 
         else:
-            raise TypeError(f"Unknown source '{source}'")
+            msg = f"Unknown source '{source}'"
+            raise TypeError(msg)
 
         return block
 
@@ -695,14 +703,16 @@ class BlockManager:
         for i, external_block in enumerate(self.external_blocks):
             if block == external_block:
                 if self._asdffile().uri is None:
-                    raise ValueError("Can't write external blocks, since URI of main file is unknown.")
+                    msg = "Can't write external blocks, since URI of main file is unknown."
+                    raise ValueError(msg)
 
                 parts = list(patched_urllib_parse.urlparse(self._asdffile().uri))
                 path = parts[2]
                 filename = os.path.basename(path)
                 return self.get_external_filename(filename, i)
 
-        raise ValueError("block not found.")
+        msg = "block not found."
+        raise ValueError(msg)
 
     def find_or_create_block_for_array(self, arr, ctx):
         """
@@ -723,16 +733,18 @@ class BlockManager:
         if isinstance(arr, ndarray.NDArrayType) and arr.block is not None:
             if arr.block in self.blocks:
                 return arr.block
-            else:
-                arr._block = None
+
+            arr._block = None
 
         base = util.get_array_base(arr)
         block = self._data_to_block_mapping.get(id(base))
         if block is not None:
             return block
+
         block = Block(base)
         self.add(block)
         self._handle_global_block_settings(ctx, block)
+
         return block
 
     def get_streamed_block(self):
@@ -797,7 +809,7 @@ class Block:
             ("used_size", "Q"),
             ("data_size", "Q"),
             ("checksum", "16s"),
-        ]
+        ],
     )
 
     def __init__(self, data=None, uri=None, array_storage="internal", memmap=True, lazy_load=True):
@@ -814,14 +826,16 @@ class Block:
         self._should_memmap = memmap
         self._memmapped = False
         self._lazy_load = lazy_load
-        self._readonly = False
 
         self.update_size()
         self._allocated = self._size
 
     def __repr__(self):
         return "<Block {} off: {} alc: {} size: {}>".format(
-            self._array_storage[:3], self._offset, self._allocated, self._size
+            self._array_storage[:3],
+            self._offset,
+            self._allocated,
+            self._size,
         )
 
     def __len__(self):
@@ -920,10 +934,6 @@ class Block:
     def checksum(self):
         return self._checksum
 
-    @property
-    def readonly(self):
-        return self._readonly
-
     def _set_checksum(self, checksum):
         if checksum == b"\0" * 16:
             self._checksum = None
@@ -933,7 +943,7 @@ class Block:
     def _calculate_checksum(self, array):
         # The following line is safe because we're only using
         # the MD5 as a checksum.
-        m = hashlib.new("md5")  # nosec
+        m = hashlib.new("md5")  # noqa: S324
         m.update(array)
         return m.digest()
 
@@ -974,7 +984,9 @@ class Block:
                 self._size = self._data_size
             else:
                 self._size = mcompression.get_compressed_size(
-                    data, self.output_compression, config=self.output_compression_kwargs
+                    data,
+                    self.output_compression,
+                    config=self.output_compression_kwargs,
                 )
         else:
             self._data_size = self._size = 0
@@ -1012,11 +1024,12 @@ class Block:
                 return None
 
             if buff not in (constants.BLOCK_MAGIC, constants.INDEX_HEADER[: len(buff)]):
-                raise ValueError(
+                msg = (
                     "Bad magic number in block. "
                     "This may indicate an internal inconsistency about the "
                     "sizes of the blocks in the file."
                 )
+                raise ValueError(msg)
 
             if buff == constants.INDEX_HEADER[: len(buff)]:
                 return None
@@ -1027,7 +1040,8 @@ class Block:
         buff = fd.read(2)
         (header_size,) = struct.unpack(b">H", buff)
         if header_size < self._header.size:
-            raise ValueError(f"Header size must be >= {self._header.size}")
+            msg = f"Header size must be >= {self._header.size}"
+            raise ValueError(msg)
 
         buff = fd.read(header_size)
         header = self._header.unpack(buff)
@@ -1038,14 +1052,16 @@ class Block:
 
         try:
             self.input_compression = header["compression"]
-        except ValueError as v:
-            raise v  # TODO: hint extension?
+        except ValueError:
+            raise  # TODO: hint extension?
 
         if self.input_compression is None and header["used_size"] != header["data_size"]:
-            raise ValueError("used_size and data_size must be equal when no compression is used.")
+            msg = "used_size and data_size must be equal when no compression is used."
+            raise ValueError(msg)
 
         if header["flags"] & constants.BLOCK_FLAG_STREAMED and self.input_compression is not None:
-            raise ValueError("Compression set on a streamed block.")
+            msg = "Compression set on a streamed block."
+            raise ValueError(msg)
 
         if fd.seekable():
             # If the file is seekable, we can delay reading the actual
@@ -1093,7 +1109,8 @@ class Block:
             fd.close()
 
         if validate_checksum and not self.validate_checksum():
-            raise ValueError(f"Block at {self._offset} does not match given checksum")
+            msg = f"Block at {self._offset} does not match given checksum"
+            raise ValueError(msg)
 
         return self
 
@@ -1103,8 +1120,8 @@ class Block:
         """
         if not self.input_compression:
             return fd.read_into_array(used_size)
-        else:
-            return mcompression.decompress(fd, used_size, data_size, self.input_compression)
+
+        return mcompression.decompress(fd, used_size, data_size, self.input_compression)
 
     def _memmap_data(self):
         """
@@ -1139,10 +1156,7 @@ class Block:
         """
         self._header_size = self._header.size
 
-        if self._data is not None:
-            data = self._flattened_data
-        else:
-            data = None
+        data = self._flattened_data if self._data is not None else None
 
         flags = 0
         data_size = used_size = allocated_size = 0
@@ -1160,12 +1174,10 @@ class Block:
         self.input_compression = self.output_compression
 
         if allocated_size < used_size:
-            raise RuntimeError(f"Block used size {used_size} larger than allocated size {allocated_size}")
+            msg = f"Block used size {used_size} larger than allocated size {allocated_size}"
+            raise RuntimeError(msg)
 
-        if self.checksum is not None:
-            checksum = self.checksum
-        else:
-            checksum = b"\0" * 16
+        checksum = self.checksum if self.checksum is not None else b"\x00" * 16
 
         fd.write(constants.BLOCK_MAGIC)
         fd.write(struct.pack(b">H", self._header_size))
@@ -1177,7 +1189,7 @@ class Block:
                 used_size=used_size,
                 data_size=data_size,
                 checksum=checksum,
-            )
+            ),
         )
 
         if data is not None:
@@ -1198,7 +1210,8 @@ class Block:
                     fd.seek(end)
             else:
                 if used_size != data_size:
-                    raise RuntimeError(f"Block used size {used_size} is not equal to the data size {data_size}")
+                    msg = f"Block used size {used_size} is not equal to the data size {data_size}"
+                    raise RuntimeError(msg)
                 fd.write_array(data)
 
     @property
@@ -1208,7 +1221,8 @@ class Block:
         """
         if self._data is None:
             if self._fd.is_closed():
-                raise OSError("ASDF file has already been closed. " "Can not get the data.")
+                msg = "ASDF file has already been closed. Can not get the data."
+                raise OSError(msg)
 
             # Be nice and reset the file position after we're done
             curpos = self._fd.tell()
@@ -1234,7 +1248,7 @@ class UnloadedBlock:
     requested.
     """
 
-    def __init__(self, fd, offset, memmap=True, lazy_load=True, readonly=False):
+    def __init__(self, fd, offset, memmap=True, lazy_load=True):
         self._fd = fd
         self._offset = offset
         self._data = None
@@ -1247,7 +1261,6 @@ class UnloadedBlock:
         self._should_memmap = memmap
         self._memmapped = False
         self._lazy_load = lazy_load
-        self._readonly = readonly
 
     def __len__(self):
         self.load()
