@@ -30,10 +30,10 @@ except ImportError:
         RESET = ""
 
 import asdf
+from asdf.tagged import Tagged
+from asdf.tags.core.ndarray import NDArrayType
+from asdf.util import human_list
 
-from ..tagged import Tagged
-from ..tags.core.ndarray import NDArrayType
-from ..util import human_list
 from .main import Command
 
 __all__ = ["diff"]
@@ -75,7 +75,10 @@ JMESPath expressions.
         parser.add_argument("filenames", metavar="asdf_file", nargs=2, help="The ASDF files to compare.")
 
         parser.add_argument(
-            "-m", "--minimal", action="store_true", help="Show minimal differences between the two files."
+            "-m",
+            "--minimal",
+            action="store_true",
+            help="Show minimal differences between the two files.",
         )
 
         parser.add_argument(
@@ -113,13 +116,13 @@ class PrintTree:
     """
 
     def __init__(self):
-        self.__tree = dict(visited=False, children=dict())
+        self.__tree = {"visited": False, "children": {}}
 
     def get_print_list(self, node_list):
         at_end = False
         print_list = []
         current = self.__tree
-        for node in ["tree"] + node_list:
+        for node in ["tree", *node_list]:
             if at_end:
                 print_list.append(node)
             elif node not in current["children"]:
@@ -135,11 +138,12 @@ class PrintTree:
 
     def __setitem__(self, node_list, visit):
         if not isinstance(node_list, list):
-            raise TypeError("node_list parameter must be an instance of list")
+            msg = "node_list parameter must be an instance of list"
+            raise TypeError(msg)
         current = self.__tree
-        for node in ["tree"] + node_list:
+        for node in ["tree", *node_list]:
             if node not in current["children"]:
-                current["children"][node] = dict(visited=True, children=dict())
+                current["children"][node] = {"visited": True, "children": {}}
             current = current["children"][node]
 
 
@@ -165,16 +169,16 @@ def print_tree_context(diff_ctx, node_list, other, use_marker, last_was_list):
     marker = THAT_MARKER if other else THIS_MARKER
     for node in diff_ctx.print_tree.get_print_list(node_list):
         if node is not None:
-            node = LIST_MARKER if isinstance(node, ArrayNode) else node + ":"
+            node_ = LIST_MARKER if isinstance(node, ArrayNode) else node + ":"
             # All of this logic is just to make the display of arrays prettier
             if use_marker:
                 line_prefix = " " if last_was_list else marker + prefix[2:]
-                line_suffix = "" if node == LIST_MARKER else RESET_NEWLINE
+                line_suffix = "" if node_ == LIST_MARKER else RESET_NEWLINE
             else:
                 line_prefix = prefix
                 line_suffix = RESET_NEWLINE
-            diff_ctx.iostream.write(line_prefix + node + line_suffix)
-            last_was_list = node == LIST_MARKER
+            diff_ctx.iostream.write(line_prefix + node_ + line_suffix)
+            last_was_list = node_ == LIST_MARKER
         prefix += "  "
     diff_ctx.print_tree[node_list] = True
     return last_was_list
@@ -189,7 +193,7 @@ def print_in_tree(diff_ctx, node_list, thing, other, use_marker=False, last_was_
             key = ArrayNode(f"{node_list[-1]}_{i}")
             last_was_list = print_in_tree(
                 diff_ctx,
-                node_list + [key],
+                [*node_list, key],
                 subthing,
                 other,
                 use_marker=True,
@@ -201,7 +205,7 @@ def print_in_tree(diff_ctx, node_list, thing, other, use_marker=False, last_was_
         for key in sorted(thing.keys()):
             last_was_list = print_in_tree(
                 diff_ctx,
-                node_list + [key],
+                [*node_list, key],
                 thing[key],
                 other,
                 use_marker=True,
@@ -218,8 +222,10 @@ def print_in_tree(diff_ctx, node_list, thing, other, use_marker=False, last_was_
     return last_was_list
 
 
-def compare_objects(diff_ctx, obj0, obj1, keys=[]):
+def compare_objects(diff_ctx, obj0, obj1, keys=None):
     """Displays diff of two objects if they are not equal"""
+    keys = [] if keys is None else keys
+
     if obj0 != obj1:
         print_in_tree(diff_ctx, keys, obj0, False, ignore_lwl=True)
         print_in_tree(diff_ctx, keys, obj1, True, ignore_lwl=True)
@@ -230,12 +236,12 @@ def print_dict_diff(diff_ctx, tree, node_list, keys, other):
     for key in keys:
         if diff_ctx.minimal:
             nodes = node_list
-            key = key
+            key_ = key
         else:
-            nodes = node_list + [key]
-            key = tree[key]
+            nodes = [*node_list, key]
+            key_ = tree[key]
         use_marker = not diff_ctx.minimal
-        print_in_tree(diff_ctx, nodes, key, other, use_marker=use_marker)
+        print_in_tree(diff_ctx, nodes, key_, other, use_marker=use_marker)
 
 
 def compare_ndarrays(diff_ctx, array0, array1, keys):
@@ -273,23 +279,27 @@ def both_are_ndarrays(tree0, tree1):
     return True
 
 
-def compare_dicts(diff_ctx, dict0, dict1, keys, ignores=set()):
+def compare_dicts(diff_ctx, dict0, dict1, keys, ignores=None):
     """Recursively compares two dictionary objects"""
+    ignores = set() if ignores is None else ignores
+
     keys0 = set(dict0.keys()) - ignores
     keys1 = set(dict1.keys()) - ignores
     # Recurse into subtree elements that are shared by both trees
     for key in sorted(keys0 & keys1):
         obj0 = dict0[key]
         obj1 = dict1[key]
-        compare_trees(diff_ctx, obj0, obj1, keys=keys + [key])
+        compare_trees(diff_ctx, obj0, obj1, keys=[*keys, key])
     # Display subtree elements existing only in this tree
     print_dict_diff(diff_ctx, dict0, keys, sorted(keys0 - keys1), False)
     # Display subtree elements existing only in that tree
     print_dict_diff(diff_ctx, dict1, keys, sorted(keys1 - keys0), True)
 
 
-def compare_trees(diff_ctx, tree0, tree1, keys=[]):
+def compare_trees(diff_ctx, tree0, tree1, keys=None):
     """Recursively traverses two ASDF tree and compares them"""
+    keys = [] if keys is None else keys
+
     if id(tree0) in diff_ctx.ignore_ids and id(tree1) in diff_ctx.ignore_ids:
         return
 
@@ -300,7 +310,7 @@ def compare_trees(diff_ctx, tree0, tree1, keys=[]):
     elif isinstance(tree0, list) and isinstance(tree1, list):
         for i, (obj0, obj1) in enumerate(zip(tree0, tree1)):
             key = ArrayNode(f"item_{i}")
-            compare_trees(diff_ctx, obj0, obj1, keys + [key])
+            compare_trees(diff_ctx, obj0, obj1, [*keys, key])
     else:
         compare_objects(diff_ctx, tree0, tree1, keys)
 
@@ -325,28 +335,28 @@ def diff(filenames, minimal, iostream=sys.stdout, ignore=None):
         List of JMESPath expressions indicating tree nodes that
         should be ignored.
     """
-    if ignore is None:
-        ignore_expressions = []
-    else:
-        ignore_expressions = [jmespath.compile(e) for e in ignore]
+    ignore_expressions = [] if ignore is None else [jmespath.compile(e) for e in ignore]
 
     try:
-        with asdf.open(filenames[0], _force_raw_types=True) as asdf0:
-            with asdf.open(filenames[1], _force_raw_types=True) as asdf1:
-                ignore_ids = set()
-                for expression in ignore_expressions:
-                    for tree in [asdf0.tree, asdf1.tree]:
-                        result = expression.search(tree)
-                        if result is not None:
-                            ignore_ids.add(id(result))
-                        if isinstance(result, list):
-                            for elem in result:
-                                ignore_ids.add(id(elem))
-                        elif isinstance(result, dict):
-                            for value in result.values():
-                                ignore_ids.add(id(value))
+        with asdf.open(filenames[0], _force_raw_types=True) as asdf0, asdf.open(
+            filenames[1],
+            _force_raw_types=True,
+        ) as asdf1:
+            ignore_ids = set()
+            for expression in ignore_expressions:
+                for tree in [asdf0.tree, asdf1.tree]:
+                    result = expression.search(tree)
+                    if result is not None:
+                        ignore_ids.add(id(result))
+                    if isinstance(result, list):
+                        for elem in result:
+                            ignore_ids.add(id(elem))
+                    elif isinstance(result, dict):
+                        for value in result.values():
+                            ignore_ids.add(id(value))
 
-                diff_ctx = DiffContext(asdf0, asdf1, iostream, minimal=minimal, ignore_ids=ignore_ids)
-                compare_trees(diff_ctx, asdf0.tree, asdf1.tree)
-    except ValueError as error:
-        raise RuntimeError(str(error))
+            diff_ctx = DiffContext(asdf0, asdf1, iostream, minimal=minimal, ignore_ids=ignore_ids)
+            compare_trees(diff_ctx, asdf0.tree, asdf1.tree)
+
+    except ValueError as err:
+        raise RuntimeError(str(err)) from err
