@@ -1,7 +1,8 @@
 """
 Implementation of command for reporting information about installed extensions.
 """
-from ..entry_points import get_extensions
+from asdf.entry_points import get_extensions
+
 from .main import Command
 
 __all__ = ["find_extensions"]
@@ -20,7 +21,10 @@ class QueryExtension(Command):  # pragma: no cover
 
         display_group = parser.add_mutually_exclusive_group()
         display_group.add_argument(
-            "-s", "--summary", action="store_true", help="Display only the installed extensions themselves"
+            "-s",
+            "--summary",
+            action="store_true",
+            help="Display only the installed extensions themselves",
         )
         display_group.add_argument(
             "-t",
@@ -38,19 +42,16 @@ class QueryExtension(Command):  # pragma: no cover
 
 
 def _format_extension(ext):
-    if ext.extension_uri is None:
-        uri = "(none)"
-    else:
-        uri = f"'{ext.extension_uri}'"
+    uri = "(none)" if ext.extension_uri is None else f"'{ext.extension_uri}'"
 
     return f"Extension URI: {uri} package: {ext.package_name} ({ext.package_version}) class: {ext.class_name}"
 
 
-def _format_type_name(typ):
-    if isinstance(typ, str):
-        return typ
-    else:
-        return f"{typ.__module__}.{typ.__name__}"
+def _format_type_name(type_):
+    if isinstance(type_, str):
+        return type_
+
+    return f"{type_.__module__}.{type_.__name__}"
 
 
 def _print_extension_details(ext, tags_only):
@@ -63,9 +64,9 @@ def _print_extension_details(ext, tags_only):
             tag_uris.append(typ.make_yaml_tag(typ.name))
 
     if len(tag_uris) > 0:
-        print("tags:")
+        print("tags:")  # noqa: T201
         for tag_uri in sorted(tag_uris):
-            print(f"  - {tag_uri}")
+            print(f"  - {tag_uri}")  # noqa: T201
 
     if not tags_only:
         types = []
@@ -76,14 +77,14 @@ def _print_extension_details(ext, tags_only):
             types.extend(typ.types)
 
         if len(types) > 0:
-            print("types:")
+            print("types:")  # noqa: T201
             for typ in sorted(types, key=_format_type_name):
-                print(f"  - {_format_type_name(typ)}")
+                print(f"  - {_format_type_name(typ)}")  # noqa: T201
 
 
 def find_extensions(summary, tags_only):
     for ext in get_extensions():
-        print(_format_extension(ext))
+        print(_format_extension(ext))  # noqa: T201
         if not summary:
             _print_extension_details(ext, tags_only)
-            print()
+            print()  # noqa: T201
