@@ -46,7 +46,8 @@ def validate(compression):
             warnings.warn(f'Found more than one compressor for "{label}"', AsdfWarning)
 
     if compression not in all_labels:
-        raise ValueError(f"Supported compression types are: {all_labels}, not '{compression}'")
+        msg = f"Supported compression types are: {all_labels}, not '{compression}'"
+        raise ValueError(msg)
 
     return compression
 
@@ -55,12 +56,13 @@ class Lz4Compressor:
     def __init__(self):
         try:
             import lz4.block
-        except ImportError:
-            raise ImportError(
+        except ImportError as err:
+            msg = (
                 "lz4 library in not installed in your Python environment, "
                 "therefore the compressed block in this ASDF file "
                 "can not be decompressed."
             )
+            raise ImportError(msg) from err
 
         self._api = lz4.block
 
@@ -83,38 +85,39 @@ class Lz4Compressor:
 
         for block in blocks:
             cast = "c"
-            block = memoryview(block).cast(cast)  # don't copy on slice
+            blk = memoryview(block).cast(cast)  # don't copy on slice
 
-            while len(block):
+            while len(blk):
                 if not _size:
                     # Don't know the (compressed) length of this block yet
-                    if len(_partial_len) + len(block) < 4:
-                        _partial_len += block
+                    if len(_partial_len) + len(blk) < 4:
+                        _partial_len += blk
                         break  # we've exhausted the block
                     if _partial_len:
                         # If we started to fill a len key, finish filling it
                         remaining = 4 - len(_partial_len)
                         if remaining:
-                            _partial_len += block[:remaining]
-                            block = block[remaining:]
+                            _partial_len += blk[:remaining]
+                            blk = blk[remaining:]
                         _size = struct.unpack("!I", _partial_len)[0]
                         _partial_len = b""
                     else:
                         # Otherwise just read the len key directly
-                        _size = struct.unpack("!I", block[:4])[0]
-                        block = block[4:]
+                        _size = struct.unpack("!I", blk[:4])[0]
+                        blk = blk[4:]
 
-                if len(block) < _size or _buffer is not None:
+                if len(blk) < _size or _buffer is not None:
                     # If we have a partial block, or we're already filling a buffer, use the buffer
                     if _buffer is None:
                         _buffer = np.empty(
-                            _size, dtype=np.byte
+                            _size,
+                            dtype=np.byte,
                         )  # use numpy instead of bytearray so we can avoid zero initialization
                         _pos = 0
-                    newbytes = min(_size - _pos, len(block))  # don't fill past the buffer len!
-                    _buffer[_pos : _pos + newbytes] = np.frombuffer(block[:newbytes], dtype=np.byte)
+                    newbytes = min(_size - _pos, len(blk))  # don't fill past the buffer len!
+                    _buffer[_pos : _pos + newbytes] = np.frombuffer(blk[:newbytes], dtype=np.byte)
                     _pos += newbytes
-                    block = block[newbytes:]
+                    blk = blk[newbytes:]
 
                     if _pos == _size:
                         _out = self._api.decompress(_buffer, return_bytearray=True, **kwargs)
@@ -124,10 +127,10 @@ class Lz4Compressor:
                         _size = 0
                 else:
                     # We have at least one full block
-                    _out = self._api.decompress(memoryview(block[:_size]), return_bytearray=True, **kwargs)
+                    _out = self._api.decompress(memoryview(blk[:_size]), return_bytearray=True, **kwargs)
                     out[bytesout : bytesout + len(_out)] = _out
                     bytesout += len(_out)
-                    block = block[_size:]
+                    blk = blk[_size:]
                     _size = 0
 
         return bytesout
@@ -180,8 +183,9 @@ def _get_compressor_from_extensions(compression, return_extension=False):
             if compression == comp.label.decode("ascii"):
                 if return_extension:
                     return comp, ext
-                else:
-                    return comp
+
+                return comp
+
     return None
 
 
@@ -211,7 +215,8 @@ def _get_compressor(label):
     elif label == "lz4":
         comp = Lz4Compressor()
     else:
-        raise ValueError(f"Unknown compression type: '{label}'")
+        msg = f"Unknown compression type: '{label}'"
+        raise ValueError(msg)
 
     return comp
 
@@ -268,7 +273,8 @@ def decompress(fd, used_size, data_size, compression, config=None):
     len_decoded = decoder.decompress(blocks, out=buffer.data, **config)
 
     if len_decoded != data_size:
-        raise ValueError("Decompressed data wrong size")
+        msg = "Decompressed data wrong size"
+        raise ValueError(msg)
 
     return buffer
 
