@@ -4,7 +4,7 @@ types.  Will eventually replace the `asdf.types` module.
 """
 import abc
 
-from ..util import get_class_name, uri_match
+from asdf.util import get_class_name, uri_match
 
 
 class Converter(abc.ABC):
@@ -18,13 +18,13 @@ class Converter(abc.ABC):
     """
 
     @classmethod
-    def __subclasshook__(cls, C):
+    def __subclasshook__(cls, class_):
         if cls is Converter:
             return (
-                hasattr(C, "tags")
-                and hasattr(C, "types")
-                and hasattr(C, "to_yaml_tree")
-                and hasattr(C, "from_yaml_tree")
+                hasattr(class_, "tags")
+                and hasattr(class_, "types")
+                and hasattr(class_, "to_yaml_tree")
+                and hasattr(class_, "from_yaml_tree")
             )
         return NotImplemented  # pragma: no cover
 
@@ -41,7 +41,6 @@ class Converter(abc.ABC):
         iterable of str
             Tag URIs or URI patterns.
         """
-        pass  # pragma: no cover
 
     @property
     @abc.abstractmethod
@@ -55,7 +54,6 @@ class Converter(abc.ABC):
         iterable of str or type
             If str, the fully qualified class name of the type.
         """
-        pass  # pragma: no cover
 
     def select_tag(self, obj, tags, ctx):
         """
@@ -119,7 +117,6 @@ class Converter(abc.ABC):
         dict or list or str
             The YAML node representation of the object.
         """
-        pass  # pragma: no cover
 
     @abc.abstractmethod
     def from_yaml_tree(self, node, tag, ctx):
@@ -152,7 +149,6 @@ class Converter(abc.ABC):
             An instance of one of the types listed in the `types` property,
             or a generator that yields such an instance.
         """
-        pass  # pragma: no cover
 
 
 class ConverterProxy(Converter):
@@ -163,7 +159,8 @@ class ConverterProxy(Converter):
 
     def __init__(self, delegate, extension):
         if not isinstance(delegate, Converter):
-            raise TypeError("Converter must implement the asdf.extension.Converter interface")
+            msg = "Converter must implement the asdf.extension.Converter interface"
+            raise TypeError(msg)
 
         self._delegate = delegate
         self._extension = extension
@@ -178,12 +175,12 @@ class ConverterProxy(Converter):
             if isinstance(tag, str):
                 relevant_tags.update(t.tag_uri for t in extension.tags if uri_match(tag, t.tag_uri))
             else:
-                raise TypeError("Converter property 'tags' must contain str values")
+                msg = "Converter property 'tags' must contain str values"
+                raise TypeError(msg)
 
         if len(relevant_tags) > 1 and not hasattr(delegate, "select_tag"):
-            raise RuntimeError(
-                "Converter handles multiple tags for this extension, but does not implement a select_tag method."
-            )
+            msg = "Converter handles multiple tags for this extension, but does not implement a select_tag method."
+            raise RuntimeError(msg)
 
         self._tags = sorted(relevant_tags)
 
@@ -192,7 +189,8 @@ class ConverterProxy(Converter):
             if isinstance(typ, (str, type)):
                 self._types.append(typ)
             else:
-                raise TypeError("Converter property 'types' must contain str or type values")
+                msg = "Converter property 'types' must contain str or type values"
+                raise TypeError(msg)
 
     @property
     def tags(self):
@@ -237,8 +235,8 @@ class ConverterProxy(Converter):
         method = getattr(self._delegate, "select_tag", None)
         if method is None:
             return self._tags[0]
-        else:
-            return method(obj, self._tags, ctx)
+
+        return method(obj, self._tags, ctx)
 
     def to_yaml_tree(self, obj, tag, ctx):
         """
@@ -344,16 +342,13 @@ class ConverterProxy(Converter):
     def __eq__(self, other):
         if isinstance(other, ConverterProxy):
             return other.delegate is self.delegate and other.extension is self.extension
-        else:
-            return False
+
+        return False
 
     def __hash__(self):
         return hash((id(self.delegate), id(self.extension)))
 
     def __repr__(self):
-        if self.package_name is None:
-            package_description = "(none)"
-        else:
-            package_description = f"{self.package_name}=={self.package_version}"
+        package_description = "(none)" if self.package_name is None else f"{self.package_name}=={self.package_version}"
 
         return f"<ConverterProxy class: {self.class_name} package: {package_description}>"
