@@ -1,17 +1,22 @@
 """
+This module is deprecated. Please see :ref:`asdf-in-fits`
+
 Utilities for embedded ADSF files in FITS.
 """
 import io
 import re
+import warnings
 
 import numpy as np
 
 from . import asdf, block, generic_io, util
+from .exceptions import AsdfDeprecationWarning
 
 try:
     from astropy.io import fits
-except ImportError:
-    raise ImportError("AsdfInFits requires astropy")
+except ImportError as err:
+    msg = "AsdfInFits requires astropy"
+    raise ImportError(msg) from err
 
 
 ASDF_EXTENSION_NAME = "ASDF"
@@ -20,6 +25,14 @@ FITS_SOURCE_PREFIX = "fits:"
 
 __all__ = ["AsdfInFits"]
 
+warnings.warn(
+    "AsdfInFits has been deprecated and will be removed in "
+    "asdf-3.0. Similar functionality has been added to stdatamodels "
+    "https://github.com/spacetelescope/stdatamodels to load and "
+    "save ASDF in fits files.",
+    AsdfDeprecationWarning,
+)
+
 
 class _FitsBlock:
     def __init__(self, hdu):
@@ -67,13 +80,12 @@ class _EmbeddedBlockManager(block.BlockManager):
             )
             if parts is not None:
                 ver = int(parts.group("ver"))
-                if parts.group("name"):
-                    pair = (parts.group("name"), ver)
-                else:
-                    pair = ver
+                pair = (parts.group("name"), ver) if parts.group("name") else ver
+
                 return _FitsBlock(self._hdulist[pair])
-            else:
-                raise ValueError(f"Can not parse source '{source}'")
+
+            msg = f"Can not parse source '{source}'"
+            raise ValueError(msg)
 
         return super().get_block(source)
 
@@ -83,14 +95,15 @@ class _EmbeddedBlockManager(block.BlockManager):
                 if hdu is block._hdu:
                     if hdu.name == "":
                         return f"{FITS_SOURCE_PREFIX}{i}"
-                    else:
-                        return f"{FITS_SOURCE_PREFIX}{hdu.name},{hdu.ver}"
-            raise ValueError("FITS block seems to have been removed")
+
+                    return f"{FITS_SOURCE_PREFIX}{hdu.name},{hdu.ver}"
+
+            msg = "FITS block seems to have been removed"
+            raise ValueError(msg)
 
         return super().get_source(block)
 
     def find_or_create_block_for_array(self, arr, ctx):
-
         base = util.get_array_base(arr)
         for hdu in self._hdulist:
             if hdu.data is None:
@@ -151,8 +164,8 @@ class AsdfInFits(asdf.AsdfFile):
         self._hdulist = hdulist
         self._close_hdulist = False
 
-    def __exit__(self, type, value, traceback):
-        super().__exit__(type, value, traceback)
+    def __exit__(self, type_, value, traceback):
+        super().__exit__(type_, value, traceback)
         if self._close_hdulist:
             self._hdulist.close()
         self._tree = {}
@@ -164,7 +177,7 @@ class AsdfInFits(asdf.AsdfFile):
         self._tree = {}
 
     @classmethod
-    def open(
+    def open(  # noqa: A003
         cls,
         fd,
         uri=None,
@@ -245,7 +258,6 @@ class AsdfInFits(asdf.AsdfFile):
         ignore_missing_extensions=False,
         **kwargs,
     ):
-
         close_hdulist = False
         if isinstance(fd, fits.hdu.hdulist.HDUList):
             hdulist = fd
@@ -256,8 +268,9 @@ class AsdfInFits(asdf.AsdfFile):
                 # Since we created this HDUList object, we need to be
                 # responsible for cleaning up upon close() or __exit__
                 close_hdulist = True
-            except OSError:
-                raise ValueError(f"Failed to parse given file '{uri}'. Is it FITS?")
+            except OSError as err:
+                msg = f"Failed to parse given file '{uri}'. Is it FITS?"
+                raise ValueError(msg) from err
 
         self = cls(
             hdulist,
@@ -294,18 +307,26 @@ class AsdfInFits(asdf.AsdfFile):
         # Allow writing to old-style ImageHDU for backwards compatibility
         if use_image_hdu:
             array = np.frombuffer(buff.getvalue(), np.uint8)
+
             return fits.ImageHDU(array, name=ASDF_EXTENSION_NAME)
-        else:
-            data = np.array(buff.getbuffer(), dtype=np.uint8)[None, :]
-            fmt = f"{len(data[0])}B"
-            column = fits.Column(array=data, format=fmt, name="ASDF_METADATA")
-            return fits.BinTableHDU.from_columns([column], name=ASDF_EXTENSION_NAME)
+
+        data = np.array(buff.getbuffer(), dtype=np.uint8)[None, :]
+        fmt = f"{len(data[0])}B"
+        column = fits.Column(array=data, format=fmt, name="ASDF_METADATA")
+
+        return fits.BinTableHDU.from_columns([column], name=ASDF_EXTENSION_NAME)
 
     def _update_asdf_extension(
-        self, all_array_storage=None, all_array_compression=None, pad_blocks=False, use_image_hdu=False, **kwargs
+        self,
+        all_array_storage=None,
+        all_array_compression=None,
+        pad_blocks=False,
+        use_image_hdu=False,
+        **kwargs,
     ):
-        if self.blocks.streamed_block is not None:
-            raise ValueError("Can not save streamed data to ASDF-in-FITS file.")
+        if self._blocks.streamed_block is not None:
+            msg = "Can not save streamed data to ASDF-in-FITS file."
+            raise ValueError(msg)
 
         buff = io.BytesIO()
         super().write_to(
@@ -331,10 +352,7 @@ class AsdfInFits(asdf.AsdfFile):
         *args,
         **kwargs,
     ):
-        if "auto_inline" in kwargs:
-            asdf_kwargs = {"auto_inline": kwargs.pop("auto_inline")}
-        else:
-            asdf_kwargs = {}
+        asdf_kwargs = {"auto_inline": kwargs.pop("auto_inline")} if "auto_inline" in kwargs else {}
 
         self._update_asdf_extension(
             all_array_storage=all_array_storage,
@@ -347,4 +365,5 @@ class AsdfInFits(asdf.AsdfFile):
         self._hdulist.writeto(filename, *args, **kwargs)
 
     def update(self, all_array_storage=None, all_array_compression=None, pad_blocks=False, **kwargs):
-        raise NotImplementedError("In-place update is not currently implemented for ASDF-in-FITS")
+        msg = "In-place update is not currently implemented for ASDF-in-FITS"
+        raise NotImplementedError(msg)
