@@ -7,11 +7,11 @@ and `JSON Pointer standard <http://tools.ietf.org/html/rfc6901>`__.
 
 import weakref
 from collections.abc import Sequence
+from contextlib import suppress
 
 import numpy as np
 
-from . import generic_io, treeutil, util
-from .types import AsdfType
+from . import _types, generic_io, treeutil, util
 from .util import patched_urllib_parse
 
 __all__ = ["resolve_fragment", "Reference", "find_references", "resolve_references", "make_reference"]
@@ -25,23 +25,24 @@ def resolve_fragment(tree, pointer):
     parts = patched_urllib_parse.unquote(pointer).split("/") if pointer else []
 
     for part in parts:
-        part = part.replace("~1", "/").replace("~0", "~")
+        part_ = part.replace("~1", "/").replace("~0", "~")
 
         if isinstance(tree, Sequence):
             # Array indexes should be turned into integers
-            try:
-                part = int(part)
-            except ValueError:
-                pass
+            with suppress(ValueError):
+                part_ = int(part_)
+
         try:
-            tree = tree[part]
-        except (TypeError, LookupError):
-            raise ValueError(f"Unresolvable reference: '{pointer}'")
+            tree = tree[part_]
+
+        except (TypeError, LookupError) as err:
+            msg = f"Unresolvable reference: '{pointer}'"
+            raise ValueError(msg) from err
 
     return tree
 
 
-class Reference(AsdfType):
+class Reference(_types.AsdfType):
     yaml_tag = "tag:yaml.org,2002:map"
 
     def __init__(self, uri, base_uri=None, asdffile=None, target=None):
@@ -67,15 +68,15 @@ class Reference(AsdfType):
         # repr alone should not force loading of the reference
         if self._target is None:
             return f"<Reference (unloaded) to '{self._uri}'>"
-        else:
-            return f"<Reference to {repr(self._target)}>"
+
+        return f"<Reference to {repr(self._target)}>"
 
     def __str__(self):
         # str alone should not force loading of the reference
         if self._target is None:
             return f"<Reference (unloaded) to '{self._uri}'>"
-        else:
-            return str(self._target)
+
+        return str(self._target)
 
     def __len__(self):
         return len(self._get_target())
@@ -85,8 +86,9 @@ class Reference(AsdfType):
             return None
         try:
             return getattr(self._get_target(), attr)
-        except Exception:
-            raise AttributeError(f"No attribute '{attr}'")
+        except Exception as err:  # noqa: BLE001
+            msg = f"No attribute '{attr}'"
+            raise AttributeError(msg) from err
 
     def __getitem__(self, item):
         return self._get_target()[item]
@@ -104,15 +106,12 @@ class Reference(AsdfType):
         return item in self._get_target()
 
     @classmethod
-    def to_tree(self, data, ctx):
-        if ctx.uri is not None:
-            uri = generic_io.relative_uri(ctx.uri, data._uri)
-        else:
-            uri = data._uri
+    def to_tree(cls, data, ctx):
+        uri = generic_io.relative_uri(ctx.uri, data._uri) if ctx.uri is not None else data._uri
         return {"$ref": uri}
 
     @classmethod
-    def validate(self, data):
+    def validate(cls, data):
         pass
 
 
@@ -167,7 +166,8 @@ def make_reference(asdffile, path):
     target = resolve_fragment(asdffile.tree, path_str)
 
     if asdffile.uri is None:
-        raise ValueError("Can not make a reference to a AsdfFile without an associated URI.")
+        msg = "Can not make a reference to a AsdfFile without an associated URI."
+        raise ValueError(msg)
     base_uri = util.get_base_uri(asdffile.uri)
     uri = base_uri + "#" + path_str
     return Reference(uri, target=target)
