@@ -14,7 +14,6 @@ __all__ = [
     "DirectoryResourceMapping",
     "ResourceManager",
     "JsonschemaResourceMapping",
-    "get_json_schema_resource_mappings",
 ]
 
 
@@ -34,15 +33,16 @@ class ResourceMappingProxy(Mapping):
     """
 
     @classmethod
-    def maybe_wrap(self, delegate):
+    def maybe_wrap(cls, delegate):
         if isinstance(delegate, ResourceMappingProxy):
             return delegate
-        else:
-            return ResourceMappingProxy(delegate)
+
+        return ResourceMappingProxy(delegate)
 
     def __init__(self, delegate, package_name=None, package_version=None):
         if not isinstance(delegate, Mapping):
-            raise TypeError("Resource mapping must implement the Mapping interface")
+            msg = "Resource mapping must implement the Mapping interface"
+            raise TypeError(msg)
 
         self._delegate = delegate
         self._package_name = package_name
@@ -107,8 +107,8 @@ class ResourceMappingProxy(Mapping):
     def __eq__(self, other):
         if isinstance(other, ResourceMappingProxy):
             return other.delegate is self.delegate
-        else:
-            return False
+
+        return False
 
     def __hash__(self):
         return hash(id(self.delegate))
@@ -145,7 +145,8 @@ class ResourceManager(Mapping):
 
     def __getitem__(self, uri):
         if uri not in self._mappings_by_uri:
-            raise KeyError(f"Resource unavailable for URI: {uri}")
+            msg = f"Resource unavailable for URI: {uri}"
+            raise KeyError(msg)
 
         content = self._mappings_by_uri[uri][uri]
         if isinstance(content, str):
@@ -190,9 +191,3 @@ class JsonschemaResourceMapping(Mapping):
 
     def __repr__(self):
         return "JsonschemaResourceMapping()"
-
-
-def get_json_schema_resource_mappings():
-    return [
-        JsonschemaResourceMapping(),
-    ]
