@@ -16,17 +16,12 @@ from jsonschema.exceptions import RefResolutionError, ValidationError
 from . import constants, extension, generic_io, reference, tagged, treeutil, util, versioning, yamlutil
 from .config import get_config
 from .exceptions import AsdfDeprecationWarning, AsdfWarning
+from .extension import _legacy
 from .util import patched_urllib_parse
 
 YAML_SCHEMA_METASCHEMA_ID = "http://stsci.edu/schemas/yaml-schema/draft-01"
 
 
-if getattr(yaml, "__with_libyaml__", None):  # pragma: no cover
-    _yaml_base_loader = yaml.CSafeLoader
-else:  # pragma: no cover
-    _yaml_base_loader = yaml.SafeLoader
-
-
 __all__ = ["validate", "fill_defaults", "remove_defaults", "check_schema"]
 
 
@@ -76,22 +71,18 @@ def validate_tag(validator, tag_pattern, instance, schema):
     tag against a pattern that may include wildcards.  See
     `asdf.util.uri_match` for details on the matching behavior.
     """
-    if hasattr(instance, "_tag"):
-        instance_tag = instance._tag
-    else:
-        # Try tags for known Python builtins
-        instance_tag = _type_to_tag(type(instance))
+    instance_tag = instance._tag if hasattr(instance, "_tag") else _type_to_tag(type(instance))
 
     if instance_tag is None:
         yield ValidationError(
-            f"mismatched tags, wanted '{tag_pattern}', got unhandled object type '{util.get_class_name(instance)}'"
+            f"mismatched tags, wanted '{tag_pattern}', got unhandled object type '{util.get_class_name(instance)}'",
         )
 
     if not util.uri_match(tag_pattern, instance_tag):
         yield ValidationError(f"mismatched tags, wanted '{tag_pattern}', got '{instance_tag}'")
 
 
-def validate_propertyOrder(validator, order, instance, schema):
+def validate_propertyOrder(validator, order, instance, schema):  # noqa: N802
     """
     Stores a value on the `tagged.TaggedDict` instance so that
     properties can be written out in the preferred order.  In that
@@ -109,7 +100,7 @@ def validate_propertyOrder(validator, order, instance, schema):
     instance.property_order = order
 
 
-def validate_flowStyle(validator, flow_style, instance, schema):
+def validate_flowStyle(validator, flow_style, instance, schema):  # noqa: N802
     """
     Sets a flag on the `tagged.TaggedList` or `tagged.TaggedDict`
     object so that the YAML generator knows which style to use to
@@ -145,7 +136,7 @@ def validate_type(validator, types, instance, schema):
     an error, otherwise falling back to the default type checker.
     """
     if isinstance(instance, datetime.datetime) and schema.get("format") == "date-time" and "string" in types:
-        return
+        return None
 
     return mvalidators.Draft4Validator.VALIDATORS["type"](validator, types, instance, schema)
 
@@ -170,7 +161,7 @@ YAML_VALIDATORS.update(
         "style": validate_style,
         "type": validate_type,
         "enum": validate_enum,
-    }
+    },
 )
 
 
@@ -178,9 +169,9 @@ def validate_fill_default(validator, properties, instance, schema):
     if not validator.is_type(instance, "object"):
         return
 
-    for property, subschema in properties.items():
+    for property_, subschema in properties.items():
         if "default" in subschema:
-            instance.setdefault(property, subschema["default"])
+            instance.setdefault(property_, subschema["default"])
 
     yield from mvalidators.Draft4Validator.VALIDATORS["properties"](validator, properties, instance, schema)
 
@@ -195,10 +186,9 @@ def validate_remove_default(validator, properties, instance, schema):
     if not validator.is_type(instance, "object"):
         return
 
-    for property, subschema in properties.items():
-        if subschema.get("default", None) is not None:
-            if instance.get(property, None) == subschema["default"]:
-                del instance[property]
+    for property_, subschema in properties.items():
+        if subschema.get("default", None) is not None and instance.get(property_, None) == subschema["default"]:
+            del instance[property_]
 
     yield from mvalidators.Draft4Validator.VALIDATORS["properties"](validator, properties, instance, schema)
 
@@ -253,30 +243,33 @@ class _ValidationContext:
 
 @lru_cache
 def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
-    meta_schema = _load_schema_cached(YAML_SCHEMA_METASCHEMA_ID, extension.get_default_resolver(), False, False)
+    meta_schema = _load_schema_cached(YAML_SCHEMA_METASCHEMA_ID, _legacy.get_default_resolver(), False, False)
 
     type_checker = mvalidators.Draft4Validator.TYPE_CHECKER.redefine_many(
         {
-            "array": lambda checker, instance: isinstance(instance, list) or isinstance(instance, tuple),
+            "array": lambda checker, instance: isinstance(instance, (list, tuple)),
             "integer": lambda checker, instance: not isinstance(instance, bool) and isinstance(instance, Integral),
             "string": lambda checker, instance: isinstance(instance, (str, np.str_)),
-        }
+        },
     )
     id_of = mvalidators.Draft4Validator.ID_OF
-    ASDFValidator = mvalidators.create(
-        meta_schema=meta_schema, validators=validators, type_checker=type_checker, id_of=id_of
+    ASDFvalidator = mvalidators.create(  # noqa: N806
+        meta_schema=meta_schema,
+        validators=validators,
+        type_checker=type_checker,
+        id_of=id_of,
     )
 
     def _patch_init(cls):
         original_init = cls.__init__
 
-        def __init__(self, *args, **kwargs):
+        def init(self, *args, **kwargs):
             self.ctx = kwargs.pop("ctx", None)
             self.serialization_context = kwargs.pop("serialization_context", None)
 
             original_init(self, *args, **kwargs)
 
-        cls.__init__ = __init__
+        cls.__init__ = init
 
     def _patch_iter_errors(cls):
         original_iter_errors = cls.iter_errors
@@ -307,7 +300,7 @@ def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
                             tag_def = self.serialization_context.extension_manager.get_tag_definition(tag)
                             schema_uris = tag_def.schema_uris
                         else:
-                            schema_uris = [self.ctx.tag_mapping(tag)]
+                            schema_uris = [self.ctx._tag_mapping(tag)]
                             if schema_uris[0] == tag:
                                 schema_uris = []
 
@@ -331,16 +324,17 @@ def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
 
         cls.iter_errors = iter_errors
 
-    _patch_init(ASDFValidator)
-    _patch_iter_errors(ASDFValidator)
+    _patch_init(ASDFvalidator)
+    _patch_iter_errors(ASDFvalidator)
 
-    return ASDFValidator
+    return ASDFvalidator
 
 
 @lru_cache
 def _load_schema(url):
     if url.startswith("http://") or url.startswith("https://") or url.startswith("asdf://"):
-        raise FileNotFoundError(f"Unable to fetch schema from non-file URL: {url}")
+        msg = f"Unable to fetch schema from non-file URL: {url}"
+        raise FileNotFoundError(msg)
 
     with generic_io.get_file(url) as fd:
         if isinstance(url, str) and url.endswith("json"):
@@ -349,7 +343,7 @@ def _load_schema(url):
         else:
             # The following call to yaml.load is safe because we're
             # using a loader that inherits from pyyaml's SafeLoader.
-            result = yaml.load(fd, Loader=yamlutil.AsdfLoader)  # nosec
+            result = yaml.load(fd, Loader=yamlutil.AsdfLoader)  # noqa: S506
     return result, fd.uri
 
 
@@ -371,7 +365,7 @@ def _make_schema_loader(resolver):
             # doesn't mind.
             # The following call to yaml.load is safe because we're
             # using a loader that inherits from pyyaml's SafeLoader.
-            result = yaml.load(content, Loader=yamlutil.AsdfLoader)  # nosec
+            result = yaml.load(content, Loader=yamlutil.AsdfLoader)  # noqa: S506
             return result, url
 
         # If not, this must be a URL (or missing).  Fall back to fetching
@@ -411,7 +405,8 @@ def _make_resolver(url_mapping):
 @lru_cache
 def load_custom_schema(url):
     warnings.warn(
-        "The 'load_custom_schema(...)' function is deprecated. Use 'load_schema' instead.", AsdfDeprecationWarning
+        "The 'load_custom_schema(...)' function is deprecated. Use 'load_schema' instead.",
+        AsdfDeprecationWarning,
     )
     return load_schema(url, resolve_references=True)
 
@@ -447,7 +442,7 @@ def load_schema(url, resolver=None, resolve_references=False, resolve_local_refs
     if resolver is None:
         # We can't just set this as the default in load_schema's definition
         # because invoking get_default_resolver at import time leads to a circular import.
-        resolver = extension.get_default_resolver()
+        resolver = _legacy.get_default_resolver()
 
     # We want to cache the work that went into constructing the schema, but returning
     # the same object is treacherous, because users who mutate the result will not
@@ -473,10 +468,7 @@ def _safe_resolve(resolver, json_id, uri):
     # parse correctly.
     parts = uri.split("#")
     base = parts[0]
-    if len(parts) > 1:
-        fragment = parts[1]
-    else:
-        fragment = ""
+    fragment = parts[1] if len(parts) > 1 else ""
 
     # The generic_io.resolve_uri method cannot operate on tag: URIs.
     # New-style extensions don't support $ref with a tag URI target anyway,
@@ -521,16 +513,16 @@ def _load_schema_cached(url, resolver, resolve_references, resolve_local_refs):
                     return node
 
                 return reference.resolve_fragment(subschema, suburl_fragment)
-            else:
-                return node
+
+            return node
 
         schema = treeutil.walk_and_modify(schema, resolve_refs)
 
-    return schema
+    return schema  # noqa: RET504
 
 
 def get_validator(
-    schema={},
+    schema=None,
     ctx=None,
     validators=None,
     url_mapping=None,
@@ -582,7 +574,8 @@ def get_validator(
 
     if validators is None:
         validators = util.HashableDict(YAML_VALIDATORS.copy())
-        validators.update(ctx.extension_list.validators)
+        validators.update(ctx._extension_list.validators)
+        validators.update(ctx._extension_manager.validator_manager.get_jsonschema_validators())
 
     kwargs["resolver"] = _make_resolver(url_mapping)
 
@@ -592,7 +585,7 @@ def get_validator(
     # test suite!!!).  Instead, we assume that the schemas are valid
     # through the running of the unit tests, not at run time.
     cls = _create_validator(validators=validators, visit_repeat_nodes=_visit_repeat_nodes)
-    return cls(schema, *args, ctx=ctx, serialization_context=_serialization_context, **kwargs)
+    return cls({} if schema is None else schema, *args, ctx=ctx, serialization_context=_serialization_context, **kwargs)
 
 
 def _validate_large_literals(instance, reading):
@@ -612,7 +605,8 @@ def _validate_large_literals(instance, reading):
                 AsdfWarning,
             )
         else:
-            raise ValidationError(f"Integer value {value} is too large to safely represent as a literal in ASDF")
+            msg = f"Integer value {value} is too large to safely represent as a literal in ASDF"
+            raise ValidationError(msg)
 
     if isinstance(instance, Integral):
         _validate(instance)
@@ -641,10 +635,11 @@ def _validate_mapping_keys(instance, reading):
                     AsdfWarning,
                 )
             else:
-                raise ValidationError(f"Mapping key {key} is not permitted.  Valid types: str, int, bool.")
+                msg = f"Mapping key {key} is not permitted.  Valid types: str, int, bool."
+                raise ValidationError(msg)
 
 
-def validate(instance, ctx=None, schema={}, validators=None, reading=False, *args, **kwargs):
+def validate(instance, ctx=None, schema=None, validators=None, reading=False, *args, **kwargs):
     """
     Validate the given instance (which must be a tagged tree) against
     the appropriate schema.  The schema itself is located using the
@@ -678,7 +673,7 @@ def validate(instance, ctx=None, schema={}, validators=None, reading=False, *arg
 
         ctx = AsdfFile()
 
-    validator = get_validator(schema, ctx, validators, ctx.resolver, *args, **kwargs)
+    validator = get_validator({} if schema is None else schema, ctx, validators, ctx._resolver, *args, **kwargs)
     validator.validate(instance)
 
     additional_validators = [_validate_large_literals]
@@ -768,9 +763,9 @@ def check_schema(schema, validate_default=True):
         applicable_validators = methodcaller("items")
 
     meta_schema_id = schema.get("$schema", YAML_SCHEMA_METASCHEMA_ID)
-    meta_schema = _load_schema_cached(meta_schema_id, extension.get_default_resolver(), False, False)
+    meta_schema = _load_schema_cached(meta_schema_id, _legacy.get_default_resolver(), False, False)
 
-    resolver = _make_resolver(extension.get_default_resolver())
+    resolver = _make_resolver(_legacy.get_default_resolver())
 
     cls = mvalidators.create(
         meta_schema=meta_schema,
