@@ -1,13 +1,12 @@
 import numpy as np
 
-from ... import util
-from ...types import AsdfType
+from asdf import _types, util
 
 
-class ComplexType(AsdfType):
+class ComplexType(_types.AsdfType):
     name = "core/complex"
     version = "1.0.0"
-    types = list(util.iter_subclasses(np.complexfloating)) + [complex]
+    types = [*list(util.iter_subclasses(np.complexfloating)), complex]
 
     @classmethod
     def to_tree(cls, node, ctx):
