@@ -5,8 +5,7 @@ import numpy as np
 from jsonschema import ValidationError
 from numpy import ma
 
-from ... import util
-from ...types import AsdfType
+from asdf import _types, util
 
 _datatype_names = {
     "int8": "i1",
@@ -31,19 +30,24 @@ _string_datatype_names = {"ascii": "S", "ucs4": "U"}
 def asdf_byteorder_to_numpy_byteorder(byteorder):
     if byteorder == "big":
         return ">"
-    elif byteorder == "little":
+
+    if byteorder == "little":
         return "<"
-    raise ValueError(f"Invalid ASDF byteorder '{byteorder}'")
+
+    msg = f"Invalid ASDF byteorder '{byteorder}'"
+    raise ValueError(msg)
 
 
 def asdf_datatype_to_numpy_dtype(datatype, byteorder=None):
     if byteorder is None:
         byteorder = sys.byteorder
+
     if isinstance(datatype, str) and datatype in _datatype_names:
         datatype = _datatype_names[datatype]
         byteorder = asdf_byteorder_to_numpy_byteorder(byteorder)
         return np.dtype(str(byteorder + datatype))
-    elif (
+
+    if (
         isinstance(datatype, list)
         and len(datatype) == 2
         and isinstance(datatype[0], str)
@@ -53,30 +57,42 @@ def asdf_datatype_to_numpy_dtype(datatype, byteorder=None):
         length = datatype[1]
         byteorder = asdf_byteorder_to_numpy_byteorder(byteorder)
         datatype = str(byteorder) + str(_string_datatype_names[datatype[0]]) + str(length)
+
         return np.dtype(datatype)
-    elif isinstance(datatype, dict):
+
+    if isinstance(datatype, dict):
         if "datatype" not in datatype:
-            raise ValueError(f"Field entry has no datatype: '{datatype}'")
+            msg = f"Field entry has no datatype: '{datatype}'"
+            raise ValueError(msg)
+
         name = datatype.get("name", "")
         byteorder = datatype.get("byteorder", byteorder)
         shape = datatype.get("shape")
         datatype = asdf_datatype_to_numpy_dtype(datatype["datatype"], byteorder)
+
         if shape is None:
             return (str(name), datatype)
-        else:
-            return (str(name), datatype, tuple(shape))
-    elif isinstance(datatype, list):
+
+        return (str(name), datatype, tuple(shape))
+
+    if isinstance(datatype, list):
         datatype_list = []
-        for i, subdatatype in enumerate(datatype):
+        for subdatatype in datatype:
             np_dtype = asdf_datatype_to_numpy_dtype(subdatatype, byteorder)
             if isinstance(np_dtype, tuple):
                 datatype_list.append(np_dtype)
+
             elif isinstance(np_dtype, np.dtype):
                 datatype_list.append(("", np_dtype))
+
             else:
-                raise RuntimeError("Error parsing asdf datatype")
+                msg = "Error parsing asdf datatype"
+                raise RuntimeError(msg)  # noqa: TRY004
+
         return np.dtype(datatype_list)
-    raise ValueError(f"Unknown datatype {datatype}")
+
+    msg = f"Unknown datatype {datatype}"
+    raise ValueError(msg)
 
 
 def numpy_byteorder_to_asdf_byteorder(byteorder, override=None):
@@ -85,10 +101,11 @@ def numpy_byteorder_to_asdf_byteorder(byteorder, override=None):
 
     if byteorder == "=":
         return sys.byteorder
-    elif byteorder == "<":
+
+    if byteorder == "<":
         return "little"
-    else:
-        return "big"
+
+    return "big"
 
 
 def numpy_dtype_to_asdf_datatype(dtype, include_byteorder=True, override_byteorder=None):
@@ -108,25 +125,26 @@ def numpy_dtype_to_asdf_datatype(dtype, include_byteorder=True, override_byteord
             fields.append(d)
         return fields, numpy_byteorder_to_asdf_byteorder(dtype.byteorder, override=override_byteorder)
 
-    elif dtype.subdtype is not None:
+    if dtype.subdtype is not None:
         return numpy_dtype_to_asdf_datatype(dtype.subdtype[0], override_byteorder=override_byteorder)
 
-    elif dtype.name in _datatype_names:
+    if dtype.name in _datatype_names:
         return dtype.name, numpy_byteorder_to_asdf_byteorder(dtype.byteorder, override=override_byteorder)
 
-    elif dtype.name == "bool":
+    if dtype.name == "bool":
         return "bool8", numpy_byteorder_to_asdf_byteorder(dtype.byteorder, override=override_byteorder)
 
-    elif dtype.name.startswith("string") or dtype.name.startswith("bytes"):
+    if dtype.name.startswith("string") or dtype.name.startswith("bytes"):
         return ["ascii", dtype.itemsize], "big"
 
-    elif dtype.name.startswith("unicode") or dtype.name.startswith("str"):
+    if dtype.name.startswith("unicode") or dtype.name.startswith("str"):
         return (
             ["ucs4", int(dtype.itemsize / 4)],
             numpy_byteorder_to_asdf_byteorder(dtype.byteorder, override=override_byteorder),
         )
 
-    raise ValueError(f"Unknown dtype {dtype}")
+    msg = f"Unknown dtype {dtype}"
+    raise ValueError(msg)
 
 
 def inline_data_asarray(inline, dtype=None):
@@ -143,7 +161,8 @@ def inline_data_asarray(inline, dtype=None):
 
         def find_innermost_match(line, depth=0):
             if not isinstance(line, list) or not len(line):
-                raise ValueError("data can not be converted to structured array")
+                msg = "data can not be converted to structured array"
+                raise ValueError(msg)
             try:
                 np.asarray(tuple(line), dtype=dtype)
             except ValueError:
@@ -156,62 +175,58 @@ def inline_data_asarray(inline, dtype=None):
         def convert_to_tuples(line, data_depth, depth=0):
             if data_depth == depth:
                 return tuple(line)
-            else:
-                return [convert_to_tuples(x, data_depth, depth + 1) for x in line]
+
+            return [convert_to_tuples(x, data_depth, depth + 1) for x in line]
 
         inline = convert_to_tuples(inline, depth)
 
         return np.asarray(inline, dtype=dtype)
-    else:
 
-        def handle_mask(inline):
-            if isinstance(inline, list):
-                if None in inline:
-                    inline_array = np.asarray(inline)
-                    nones = np.equal(inline_array, None)
-                    return np.ma.array(np.where(nones, 0, inline), mask=nones)
-                else:
-                    return [handle_mask(x) for x in inline]
-            return inline
+    def handle_mask(inline):
+        if isinstance(inline, list):
+            if None in inline:
+                inline_array = np.asarray(inline)
+                nones = np.equal(inline_array, None)
+                return np.ma.array(np.where(nones, 0, inline), mask=nones)
 
-        inline = handle_mask(inline)
+            return [handle_mask(x) for x in inline]
 
-        inline = np.ma.asarray(inline, dtype=dtype)
-        if not ma.is_masked(inline):
-            return inline.data
-        else:
-            return inline
+        return inline
+
+    inline = handle_mask(inline)
+
+    inline = np.ma.asarray(inline, dtype=dtype)
+    if not ma.is_masked(inline):
+        return inline.data
+
+    return inline
 
 
 def numpy_array_to_list(array):
     def tolist(x):
         if isinstance(x, (np.ndarray, NDArrayType)):
-            if x.dtype.char == "S":
-                x = x.astype("U").tolist()
-            else:
-                x = x.tolist()
+            x = x.astype("U").tolist() if x.dtype.char == "S" else x.tolist()
 
         if isinstance(x, (list, tuple)):
             return [tolist(y) for y in x]
-        else:
-            return x
+
+        return x
 
     def ascii_to_unicode(x):
         # Convert byte string arrays to unicode string arrays, since YAML
         # doesn't handle the former.
         if isinstance(x, list):
             return [ascii_to_unicode(y) for y in x]
-        elif isinstance(x, bytes):
+
+        if isinstance(x, bytes):
             return x.decode("ascii")
-        else:
-            return x
 
-    result = ascii_to_unicode(tolist(array))
+        return x
 
-    return result
+    return ascii_to_unicode(tolist(array))
 
 
-class NDArrayType(AsdfType):
+class NDArrayType(_types.AsdfType):
     name = "core/ndarray"
     version = "1.0.0"
     supported_versions = {"1.0.0", "1.1.0"}
@@ -227,19 +242,19 @@ class NDArrayType(AsdfType):
         if isinstance(source, list):
             self._array = inline_data_asarray(source, dtype)
             self._array = self._apply_mask(self._array, self._mask)
-            self._block = asdffile.blocks.add_inline(self._array)
-            if shape is not None:
-                if (shape[0] == "*" and self._array.shape[1:] != tuple(shape[1:])) or (
-                    self._array.shape != tuple(shape)
-                ):
-                    raise ValueError("inline data doesn't match the given shape")
+            self._block = asdffile._blocks.add_inline(self._array)
+            if shape is not None and (
+                (shape[0] == "*" and self._array.shape[1:] != tuple(shape[1:])) or (self._array.shape != tuple(shape))
+            ):
+                msg = "inline data doesn't match the given shape"
+                raise ValueError(msg)
 
         self._shape = shape
         self._dtype = dtype
         self._offset = offset
         self._strides = strides
         self._order = order
-        if not asdffile.blocks.lazy_load:
+        if not asdffile._blocks.lazy_load:
             self._make_array()
 
     def _make_array(self):
@@ -257,15 +272,10 @@ class NDArrayType(AsdfType):
             block = self.block
             shape = self.get_actual_shape(self._shape, self._strides, self._dtype, len(block))
 
-            if block.trust_data_dtype:
-                dtype = block.data.dtype
-            else:
-                dtype = self._dtype
+            dtype = block.data.dtype if block.trust_data_dtype else self._dtype
 
             self._array = np.ndarray(shape, dtype, block.data, self._offset, self._strides, self._order)
             self._array = self._apply_mask(self._array, self._mask)
-            if block.readonly:
-                self._array.setflags(write=False)
         return self._array
 
     def _apply_mask(self, array, mask):
@@ -274,13 +284,14 @@ class NDArrayType(AsdfType):
             # memmapped mask array is freed properly when the masked
             # array goes away.
             array = ma.array(array, mask=mask.view())
-            # assert util.get_array_base(array.mask) is util.get_array_base(mask)
             return array
-        elif np.isscalar(mask):
+
+        if np.isscalar(mask):
             if np.isnan(mask):
                 return ma.array(array, mask=np.isnan(array))
-            else:
-                return ma.masked_values(array, mask)
+
+            return ma.masked_values(array, mask)
+
         return array
 
     def __array__(self):
@@ -312,21 +323,24 @@ class NDArrayType(AsdfType):
         num_stars = shape.count("*")
         if num_stars == 0:
             return shape
-        elif num_stars == 1:
+
+        if num_stars == 1:
             if shape[0] != "*":
-                raise ValueError("'*' may only be in first entry of shape")
-            if strides is not None:
-                stride = strides[0]
-            else:
-                stride = np.product(shape[1:]) * dtype.itemsize
+                msg = "'*' may only be in first entry of shape"
+                raise ValueError(msg)
+
+            stride = strides[0] if strides is not None else np.prod(shape[1:]) * dtype.itemsize
+
             missing = int(block_size / stride)
             return [missing] + shape[1:]
-        raise ValueError(f"Invalid shape '{shape}'")
+
+        msg = f"Invalid shape '{shape}'"
+        raise ValueError(msg)
 
     @property
     def block(self):
         if self._block is None:
-            self._block = self._asdffile.blocks.get_block(self._source)
+            self._block = self._asdffile._blocks.get_block(self._source)
         return self._block
 
     @property
@@ -341,21 +355,21 @@ class NDArrayType(AsdfType):
     def dtype(self):
         if self._array is None:
             return self._dtype
-        else:
-            return self._make_array().dtype
+
+        return self._make_array().dtype
 
     def __len__(self):
         if self._array is None:
             return self._shape[0]
-        else:
-            return len(self._make_array())
+
+        return len(self._make_array())
 
     def __getattr__(self, attr):
         # We need to ignore __array_struct__, or unicode arrays end up
         # getting "double casted" and upsized.  This also reduces the
         # number of array creations in the general case.
         if attr == "__array_struct__":
-            raise AttributeError()
+            raise AttributeError
         return getattr(self._make_array(), attr)
 
     def __setitem__(self, *args):
@@ -364,9 +378,10 @@ class NDArrayType(AsdfType):
         # originates from the call to __repr__ inside the traceback report.
         try:
             self._make_array().__setitem__(*args)
-        except Exception as e:
+        except Exception:
             self._array = None
-            raise e from None
+
+            raise
 
     def __getattribute__(self, name):
         # The presence of these attributes on an NDArrayType instance
@@ -374,45 +389,42 @@ class NDArrayType(AsdfType):
         # libraries.
         # See https://github.com/asdf-format/asdf/issues/1015
         if name in ("name", "version", "supported_versions"):
-            raise AttributeError(f"'{self.__class__.name}' object has no attribute '{name}'")
-        else:
-            return AsdfType.__getattribute__(self, name)
+            msg = f"'{self.__class__.name}' object has no attribute '{name}'"
+            raise AttributeError(msg)
+
+        return _types.AsdfType.__getattribute__(self, name)
 
     @classmethod
     def from_tree(cls, node, ctx):
         if isinstance(node, list):
             return cls(node, None, None, None, None, None, None, ctx)
 
-        elif isinstance(node, dict):
+        if isinstance(node, dict):
             source = node.get("source")
             data = node.get("data")
             if source and data:
-                raise ValueError("Both source and data may not be provided at the same time")
+                msg = "Both source and data may not be provided at the same time"
+                raise ValueError(msg)
             if data:
                 source = data
             shape = node.get("shape", None)
-            if data is not None:
-                byteorder = sys.byteorder
-            else:
-                byteorder = node["byteorder"]
-            if "datatype" in node:
-                dtype = asdf_datatype_to_numpy_dtype(node["datatype"], byteorder)
-            else:
-                dtype = None
+            byteorder = sys.byteorder if data is not None else node["byteorder"]
+            dtype = asdf_datatype_to_numpy_dtype(node["datatype"], byteorder) if "datatype" in node else None
             offset = node.get("offset", 0)
             strides = node.get("strides", None)
             mask = node.get("mask", None)
 
             return cls(source, shape, dtype, offset, strides, "A", mask, ctx)
 
-        raise TypeError("Invalid ndarray description.")
+        msg = "Invalid ndarray description."
+        raise TypeError(msg)
 
     @classmethod
     def reserve_blocks(cls, data, ctx):
         # Find all of the used data buffers so we can add or rearrange
         # them if necessary
         if isinstance(data, np.ndarray):
-            yield ctx.blocks.find_or_create_block_for_array(data, ctx)
+            yield ctx._blocks.find_or_create_block_for_array(data, ctx)
         elif isinstance(data, NDArrayType):
             yield data.block
 
@@ -434,7 +446,7 @@ class NDArrayType(AsdfType):
 
         shape = data.shape
 
-        block = ctx.blocks.find_or_create_block_for_array(data, ctx)
+        block = ctx._blocks.find_or_create_block_for_array(data, ctx)
 
         if block.array_storage == "fits":
             # Views over arrays stored in FITS files have some idiosyncrasies.
@@ -447,12 +459,13 @@ class NDArrayType(AsdfType):
                 or block.data.ctypes.data != data.ctypes.data
                 or block.data.strides != data.strides
             ):
-                raise ValueError(
+                msg = (
                     "ASDF has only limited support for serializing views over arrays stored "
                     "in FITS HDUs.  This error likely means that a slice of such an array "
                     "was found in the ASDF tree.  The slice can be decoupled from the FITS "
                     "array by calling copy() before assigning it to the tree."
                 )
+                raise ValueError(msg)
 
             offset = 0
             strides = None
@@ -466,10 +479,7 @@ class NDArrayType(AsdfType):
             # block data, in case the block is compressed.
             offset = data.ctypes.data - base.ctypes.data
 
-            if data.flags.c_contiguous:
-                strides = None
-            else:
-                strides = data.strides
+            strides = None if data.flags.c_contiguous else data.strides
 
             dtype, byteorder = numpy_dtype_to_asdf_datatype(
                 data.dtype,
@@ -486,12 +496,13 @@ class NDArrayType(AsdfType):
             listdata = numpy_array_to_list(data)
             result["data"] = listdata
             result["datatype"] = dtype
+
         else:
             result["shape"] = list(shape)
             if block.array_storage == "streamed":
                 result["shape"][0] = "*"
 
-            result["source"] = ctx.blocks.get_source(block)
+            result["source"] = ctx._blocks.get_source(block)
             result["datatype"] = dtype
             result["byteorder"] = byteorder
 
@@ -501,11 +512,11 @@ class NDArrayType(AsdfType):
             if strides is not None:
                 result["strides"] = list(strides)
 
-        if isinstance(data, ma.MaskedArray):
-            if np.any(data.mask):
-                if block.array_storage == "inline":
-                    ctx.blocks.set_array_storage(ctx.blocks[data.mask], "inline")
-                result["mask"] = data.mask
+        if isinstance(data, ma.MaskedArray) and np.any(data.mask):
+            if block.array_storage == "inline":
+                ctx._blocks.set_array_storage(ctx._blocks[data.mask], "inline")
+
+            result["mask"] = data.mask
 
         return result
 
@@ -515,7 +526,8 @@ class NDArrayType(AsdfType):
             if not new.dtype.fields:
                 # This line is safe because this is actually a piece of test
                 # code, even though it lives in this file:
-                assert False, "arrays not equal"  # nosec
+                msg = "arrays not equal"
+                raise AssertionError(msg)
             for a, b in zip(old, new):
                 cls._assert_equality(a, b, func)
         else:
@@ -530,7 +542,7 @@ class NDArrayType(AsdfType):
                 new = new.tolist()
                 # This line is safe because this is actually a piece of test
                 # code, even though it lives in this file:
-                assert old == new  # nosec
+                assert old == new  # noqa: S101
             else:
                 func(old, new)
 
@@ -553,21 +565,19 @@ class NDArrayType(AsdfType):
     def copy_to_new_asdf(cls, node, asdffile):
         if isinstance(node, NDArrayType):
             array = node._make_array()
-            asdffile.blocks.set_array_storage(asdffile.blocks[array], node.block.array_storage)
+            asdffile._blocks.set_array_storage(asdffile._blocks[array], node.block.array_storage)
             return node._make_array()
         return node
 
 
 def _make_operation(name):
-    def __operation__(self, *args):
+    def operation(self, *args):
         return getattr(self._make_array(), name)(*args)
 
-    return __operation__
+    return operation
 
 
-classes_to_modify = NDArrayType.__versioned_siblings + [
-    NDArrayType,
-]
+classes_to_modify = [*NDArrayType.__versioned_siblings, NDArrayType]
 for op in [
     "__neg__",
     "__pos__",
@@ -640,15 +650,20 @@ def _get_ndim(instance):
     if isinstance(instance, list):
         array = inline_data_asarray(instance)
         return array.ndim
-    elif isinstance(instance, dict):
+
+    if isinstance(instance, dict):
         if "shape" in instance:
             return len(instance["shape"])
-        elif "data" in instance:
+
+        if "data" in instance:
             array = inline_data_asarray(instance["data"])
             return array.ndim
-    elif isinstance(instance, (np.ndarray, NDArrayType)):
+
+    if isinstance(instance, (np.ndarray, NDArrayType)):
         return len(instance.shape)
 
+    return None
+
 
 def validate_ndim(validator, ndim, instance, schema):
     in_ndim = _get_ndim(instance)
@@ -678,11 +693,13 @@ def validate_datatype(validator, datatype, instance, schema):
             array = inline_data_asarray(instance["data"])
             in_datatype, _ = numpy_dtype_to_asdf_datatype(array.dtype)
         else:
-            raise ValidationError("Not an array")
+            msg = "Not an array"
+            raise ValidationError(msg)
     elif isinstance(instance, (np.ndarray, NDArrayType)):
         in_datatype, _ = numpy_dtype_to_asdf_datatype(instance.dtype)
     else:
-        raise ValidationError("Not an array")
+        msg = "Not an array"
+        raise ValidationError(msg)
 
     if datatype == in_datatype:
         return
@@ -714,8 +731,5 @@ def validate_datatype(validator, datatype, instance, schema):
                 yield ValidationError(
                     "Can not safely cast to expected datatype: "
                     f"Expected {numpy_dtype_to_asdf_datatype(out_type)[0]}, "
-                    f"got {numpy_dtype_to_asdf_datatype(in_type)[0]}"
+                    f"got {numpy_dtype_to_asdf_datatype(in_type)[0]}",
                 )
-
-
-NDArrayType.validators = {"ndim": validate_ndim, "max_ndim": validate_max_ndim, "datatype": validate_datatype}
