@@ -76,8 +76,8 @@ def human_list(line, separator="and"):
     """
     if len(line) == 1:
         return line[0]
-    else:
-        return ", ".join(line[:-1]) + " " + separator + " " + line[-1]
+
+    return ", ".join(line[:-1]) + " " + separator + " " + line[-1]
 
 
 def get_array_base(arr):
@@ -98,7 +98,7 @@ def get_base_uri(uri):
     For a given URI, return the part without any fragment.
     """
     parts = patched_urllib_parse.urlparse(uri)
-    return patched_urllib_parse.urlunparse(list(parts[:5]) + [""])
+    return patched_urllib_parse.urlunparse([*list(parts[:5]), ""])
 
 
 def filepath_to_url(path):
@@ -195,7 +195,8 @@ class BinaryStruct:
         fields = [0] * len(self._names)
         for key, val in kwargs.items():
             if key not in self._offsets:
-                raise KeyError(f"No header field '{key}'")
+                msg = f"No header field '{key}'"
+                raise KeyError(msg)
             i = self._names.index(key)
             fields[i] = val
         return struct.pack(self._fmt, *fields)
@@ -224,12 +225,13 @@ class BinaryStruct:
         updates = []
         for key, val in kwargs.items():
             if key not in self._offsets:
-                raise KeyError(f"No header field '{key}'")
+                msg = f"No header field '{key}'"
+                raise KeyError(msg)
             updates.append((self._offsets[key], val))
         updates.sort()
 
         start = fd.tell()
-        for ((offset, datatype), val) in updates:
+        for (offset, datatype), val in updates:
             fd.seek(start + offset)
             fd.write(struct.pack(datatype, val))
 
@@ -302,8 +304,8 @@ def resolve_name(name):
     for part in parts[cursor:]:
         try:
             ret = getattr(ret, part)
-        except AttributeError:
-            raise ImportError(name)
+        except AttributeError as err:
+            raise ImportError(name) from err
 
     return ret
 
@@ -369,11 +371,8 @@ def minversion(module, version, inclusive=True):
         except ImportError:
             return False
     else:
-        raise ValueError(
-            "module argument must be an actual imported "
-            "module, or the import name of the module; "
-            f"got {repr(module)}"
-        )
+        msg = f"module argument must be an actual imported module, or the import name of the module; got {repr(module)}"
+        raise ValueError(msg)  # noqa: TRY004
 
     if module_version is None:
         try:
@@ -388,8 +387,8 @@ def minversion(module, version, inclusive=True):
 
     if inclusive:
         return Version(module_version) >= Version(version)
-    else:
-        return Version(module_version) > Version(version)
+
+    return Version(module_version) > Version(version)
 
 
 class InheritDocstrings(type):
@@ -459,14 +458,7 @@ def is_primitive(value):
     bool
         True if the value is primitive, False otherwise
     """
-    return (
-        value is None
-        or isinstance(value, bool)
-        or isinstance(value, int)
-        or isinstance(value, float)
-        or isinstance(value, complex)
-        or isinstance(value, str)
-    )
+    return isinstance(value, (bool, int, float, complex, str)) or value is None
 
 
 def uri_match(pattern, uri):
@@ -495,8 +487,8 @@ def uri_match(pattern, uri):
 
     if "*" in pattern:
         return _compile_uri_match_pattern(pattern).fullmatch(uri) is not None
-    else:
-        return pattern == uri
+
+    return pattern == uri
 
 
 @lru_cache(1024)
@@ -524,10 +516,11 @@ def get_file_type(fd):
     """
     if fd.peek(5) == constants.ASDF_MAGIC:
         return FileType.ASDF
-    elif fd.peek(6) == constants.FITS_MAGIC:
+
+    if fd.peek(6) == constants.FITS_MAGIC:
         return FileType.FITS
-    else:
-        return FileType.UNKNOWN
+
+    return FileType.UNKNOWN
 
 
 class FileType(enum.Enum):
