@@ -6,14 +6,11 @@ of the ASDF spec.
 from functools import total_ordering
 
 import yaml
-
-if getattr(yaml, "__with_libyaml__", None):  # pragma: no cover
-    _yaml_base_loader = yaml.CSafeLoader
-else:  # pragma: no cover
-    _yaml_base_loader = yaml.SafeLoader
-
 from semantic_version import SimpleSpec, Version
 
+_yaml_base_loader = yaml.CSafeLoader if getattr(yaml, "__with_libyaml__", None) else yaml.SafeLoader
+
+
 __all__ = ["AsdfVersion", "AsdfSpec", "AsdfVersionMixin", "split_tag_version", "join_tag_version"]
 
 
@@ -43,7 +40,9 @@ def get_version_map(version):
         from .config import get_config
 
         uri = f"http://stsci.edu/schemas/asdf/version_map-{version}"
-        version_map = yaml.load(get_config().resource_manager[uri], Loader=_yaml_base_loader)  # nosec
+        # The following call to yaml.load is safe because we're
+        # using a loader that inherits from pyyaml's SafeLoader.
+        version_map = yaml.load(get_config().resource_manager[uri], Loader=_yaml_base_loader)  # noqa: S506
 
         # Separate the core tags from the rest of the standard for convenience
         version_map["core"] = {}
@@ -123,14 +122,12 @@ class AsdfSpec(SimpleSpec):
 
     def __iterate_versions(self, versions):
         for v in versions:
-            if isinstance(v, (str, tuple, list)):
-                v = AsdfVersion(v)
-            yield v
+            yield AsdfVersion(v) if isinstance(v, (str, tuple, list)) else v
 
     def select(self, versions):
         return super().select(self.__iterate_versions(versions))
 
-    def filter(self, versions):
+    def filter(self, versions):  # noqa: A003
         return super().filter(self.__iterate_versions(versions))
 
     def __eq__(self, other):
