@@ -9,17 +9,12 @@ from . import schema, tagged, treeutil, util
 from .constants import STSCI_SCHEMA_TAG_BASE, YAML_TAG_PREFIX
 from .exceptions import AsdfConversionWarning
 from .tags.core import AsdfObject
-from .versioning import split_tag_version
+from .versioning import _yaml_base_loader, split_tag_version
 
 __all__ = ["custom_tree_to_tagged_tree", "tagged_tree_to_custom_tree"]
 
 
-if getattr(yaml, "__with_libyaml__", None):  # pragma: no cover
-    _yaml_base_dumper = yaml.CSafeDumper
-    _yaml_base_loader = yaml.CSafeLoader
-else:  # pragma: no cover
-    _yaml_base_dumper = yaml.SafeDumper
-    _yaml_base_loader = yaml.SafeLoader
+_yaml_base_dumper = yaml.CSafeDumper if getattr(yaml, "__with_libyaml__", None) else yaml.SafeDumper
 
 
 YAML_OMAP_TAG = YAML_TAG_PREFIX + "omap"
@@ -149,12 +144,14 @@ class AsdfLoader(_yaml_base_loader):
     def construct_undefined(self, node):
         if isinstance(node, yaml.MappingNode):
             return self._construct_tagged_mapping(node)
-        elif isinstance(node, yaml.SequenceNode):
+
+        if isinstance(node, yaml.SequenceNode):
             return self._construct_tagged_sequence(node)
-        elif isinstance(node, yaml.ScalarNode):
+
+        if isinstance(node, yaml.ScalarNode):
             return self._construct_tagged_scalar(node)
-        else:
-            return super().construct_undefined(node)
+
+        return super().construct_undefined(node)
 
     def _construct_tagged_mapping(self, node):
         data = tagged.tag_object(node.tag, {})
@@ -175,23 +172,26 @@ class AsdfLoader(_yaml_base_loader):
         omap = OrderedDict()
         yield omap
         if not isinstance(node, yaml.SequenceNode):
+            msg = "while constructing an ordered map"
             raise yaml.ConstructorError(
-                "while constructing an ordered map",
+                msg,
                 node.start_mark,
-                "expected a sequence, but found %s" % node.id,
+                f"expected a sequence, but found {node.id}",
                 node.start_mark,
             )
         for subnode in node.value:
             if not isinstance(subnode, yaml.MappingNode):
+                msg = "while constructing an ordered map"
                 raise yaml.ConstructorError(
-                    "while constructing an ordered map",
+                    msg,
                     node.start_mark,
                     f"expected a mapping of length 1, but found {subnode.id}",
                     subnode.start_mark,
                 )
             if len(subnode.value) != 1:
+                msg = "while constructing an ordered map"
                 raise yaml.ConstructorError(
-                    "while constructing an ordered map",
+                    msg,
                     node.start_mark,
                     f"expected a single mapping item, but found {len(subnode.value): %d} items",
                     subnode.start_mark,
@@ -238,7 +238,8 @@ def custom_tree_to_tagged_tree(tree, ctx, _serialization_context=None):
             tagged_node = tagged.TaggedString(node)
             tagged_node._tag = tag
         else:
-            raise TypeError(f"Converter returned illegal node type: {util.get_class_name(node)}")
+            msg = f"Converter returned illegal node type: {util.get_class_name(node)}"
+            raise TypeError(msg)
 
         _serialization_context._mark_extension_used(converter.extension)
 
@@ -249,14 +250,17 @@ def custom_tree_to_tagged_tree(tree, ctx, _serialization_context=None):
     def _walker(obj):
         if extension_manager.handles_type(type(obj)):
             return _convert_obj(obj)
-        else:
-            tag = ctx.type_index.from_custom_type(
-                type(obj), ctx.version_string, _serialization_context=_serialization_context
-            )
 
-            if tag is not None:
-                return tag.to_tree_tagged(obj, ctx)
-            return obj
+        tag = ctx._type_index.from_custom_type(
+            type(obj),
+            ctx.version_string,
+            _serialization_context=_serialization_context,
+        )
+
+        if tag is not None:
+            return tag.to_tree_tagged(obj, ctx)
+
+        return obj
 
     return treeutil.walk_and_modify(
         tree,
@@ -293,7 +297,7 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
             _serialization_context._mark_extension_used(converter.extension)
             return obj
 
-        tag_type = ctx.type_index.from_yaml_tag(ctx, tag, _serialization_context=_serialization_context)
+        tag_type = ctx._type_index.from_yaml_tag(ctx, tag, _serialization_context=_serialization_context)
         # This means the tag did not correspond to any type in our type index.
         if tag_type is None:
             if not ctx._ignore_unrecognized_tag:
@@ -323,7 +327,7 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
             return tag_type.from_tree_tagged(node, ctx)
         except TypeError as err:
             warnings.warn(
-                f"Failed to convert {tag} to custom type (detail: {err}). " "Using raw Python data structure instead",
+                f"Failed to convert {tag} to custom type (detail: {err}). Using raw Python data structure instead",
                 AsdfConversionWarning,
             )
 
@@ -351,7 +355,7 @@ def load_tree(stream):
     """
     # The following call to yaml.load is safe because we're
     # using a loader that inherits from pyyaml's SafeLoader.
-    return yaml.load(stream, Loader=AsdfLoader)  # nosec
+    return yaml.load(stream, Loader=AsdfLoader)  # noqa: S506
 
 
 def dump_tree(tree, fd, ctx, tree_finalizer=None, _serialization_context=None):
@@ -380,7 +384,8 @@ def dump_tree(tree, fd, ctx, tree_finalizer=None, _serialization_context=None):
     # types.  In 3.0, it will be passed as the `ctx` instead of the
     # AsdfFile itself.
     if type(tree) is not AsdfObject:
-        raise TypeError("Root node of ASDF tree must be of type AsdfObject")
+        msg = "Root node of ASDF tree must be of type AsdfObject"
+        raise TypeError(msg)
 
     tags = {"!": STSCI_SCHEMA_TAG_BASE + "/"}
     tree = custom_tree_to_tagged_tree(tree, ctx, _serialization_context=_serialization_context)
