@@ -1,3 +1,5 @@
+# noqa: INP001
+
 import numpy as np
 
 import asdf
@@ -6,11 +8,11 @@ from asdf.versioning import supported_versions
 
 def generate_file(path, version):
     if version not in supported_versions:
-        raise ValueError(
-            "ASDF Standard version {} is not supported by version {} of the asdf library".format(
-                version, asdf.__version__
-            )
+        msg = "ASDF Standard version {} is not supported by version {} of the asdf library".format(
+            version,
+            asdf.__version__,
         )
+        raise ValueError(msg)
 
     af = asdf.AsdfFile({"array": np.ones((8, 16))}, version=version)
     af.write_to(path)
