@@ -1,3 +1,5 @@
+# noqa: INP001
+
 import json
 import os
 import subprocess
@@ -83,7 +85,7 @@ def env_run(env_path, command, *args, **kwargs):
     Run a command on the context of the virtual environment at
     the specified path.
     """
-    return subprocess.run([env_path / "bin" / command] + list(args), **kwargs).returncode == 0
+    return subprocess.run([env_path / "bin" / command, *list(args)], **kwargs).returncode == 0
 
 
 def env_check_output(env_path, command, *args):
@@ -91,7 +93,7 @@ def env_check_output(env_path, command, *args):
     Run a command on the context of the virtual environment at
     the specified path, and return the output.
     """
-    return subprocess.check_output([env_path / "bin" / command] + list(args)).decode("utf-8").strip()
+    return subprocess.check_output([env_path / "bin" / command, *list(args)]).decode("utf-8").strip()
 
 
 def get_supported_versions(env_path):
@@ -131,14 +133,18 @@ def env_path(asdf_version, tmp_path_factory):
     assert subprocess.run(["virtualenv", str(path)]).returncode == 0
 
     assert env_run(
-        path, "pip", "install", f"asdf=={asdf_version}", capture_output=True
+        path,
+        "pip",
+        "install",
+        f"asdf=={asdf_version}",
+        capture_output=True,
     ), f"Failed to install asdf version {asdf_version}"
 
     return path
 
 
 @pytest.fixture(autouse=True)
-def pushd_tmpdir(tmpdir):
+def _pushd_tmpdir(tmpdir):
     """
     Change the working directory, in case the user is running these
     tests from the repo root.  Python will import a module from the
@@ -151,21 +157,21 @@ def pushd_tmpdir(tmpdir):
     os.chdir(original_cwd)
 
 
-@pytest.mark.remote_data
+@pytest.mark.remote_data()
 def test_file_compatibility(asdf_version, env_path, tmpdir):
     # Sanity check to ensure we're not accidentally comparing
     # the current code to itself.
     installed_version = get_installed_version(env_path)
     assert installed_version == asdf_version, (
         f"The version of asdf in the virtualenv ({installed_version}) does "
-        + f"not match the version being tested ({asdf_version})"
+        f"not match the version being tested ({asdf_version})"
     )
 
     # We can only test ASDF Standard versions that both library
     # versions support.
     current_supported_versions = set(asdf.versioning.supported_versions)
     old_supported_versions = set(get_supported_versions(env_path))
-    standard_versions = [v for v in current_supported_versions.intersection(old_supported_versions)]
+    standard_versions = list(current_supported_versions.intersection(old_supported_versions))
 
     # Confirm that this test isn't giving us a false sense of security.
     assert len(standard_versions) > 0
@@ -178,7 +184,7 @@ def test_file_compatibility(asdf_version, env_path, tmpdir):
             generate_file(current_file_path, standard_version)
             assert env_run(env_path, "python3", ASSERT_SCRIPT_PATH, current_file_path, capture_output=True), (
                 f"asdf library version {asdf_version} failed to read an ASDF Standard {standard_version} "
-                + "file produced by this code"
+                "file produced by this code"
             )
 
         # Confirm that a file generated by the older version of the library
@@ -186,11 +192,17 @@ def test_file_compatibility(asdf_version, env_path, tmpdir):
         if asdf_version >= MIN_VERSION_OLD_FILES:
             old_file_path = Path(str(tmpdir)) / "test-old.asdf"
             assert env_run(
-                env_path, "python3", GENERATE_SCRIPT_PATH, old_file_path, str(standard_version), capture_output=True
+                env_path,
+                "python3",
+                GENERATE_SCRIPT_PATH,
+                old_file_path,
+                str(standard_version),
+                capture_output=True,
             ), "asdf library version {} failed to generate an ASDF Standard {} file".format(
-                asdf_version, standard_version
+                asdf_version,
+                standard_version,
             )
             assert_file_correct(old_file_path), (
-                f"asdf library version {asdf_version} produced an ASDF Standard {standard_version} "
-                + "that this code failed to read"
+                f"asdf library version {asdf_version} produced an ASDF Standard {standard_version}"
+                "that this code failed to read"
             )
